<?php
  class AnomateHelperApi {
    public function __construct() {
      add_action('rest_api_init', array($this, 'includes'), 5);
    }

    public function includes() {
      require_once 'api/anomate.php';
      require_once 'api/posts.php';
    }

    public function get_items_permissions_check($request) {
      if ( !wc_rest_check_user_permissions('read') ) {
        return new WP_Error( 'weoocommerce_rest_cannot_view', __('Sorry, you cannot list resources', 'anomate-helper'), array(
          'status' => rest_authorization_required_code(),
        ) );
      }

      return true;
    }

    public function update_items_permissions_check() {
      if ( !wc_rest_check_user_permissions('create') ) {
        return new WP_Error('woocommerce_rest_cannot_create', __('Sorry, you are not allowed to create resources.', 'anomate-helper'), array(
          'status' => rest_authorization_required_code(),
        ) );
      }

      return true;
    }

    public function get_webhook_headers($webhook) {
      return array(
        'Content-Type' => 'application/json',
        'X-WC-Webhook-Resource' => $webhook['resource'],
        'X-WC-Webhook-Topic' => $webhook['resource'] . '.' . $webhook['event'],
        'X-WC-Webhook-Event' => $webhook['event'],
      );
    }

    public function get_post_object($id) {
      return array(
        'id' => $id,
        'title' => get_the_title($id),
        'thumbnail_url' => get_the_post_thumbnail_url($id, 'full'),
        'content' => get_the_content(null, false, $id),
        'permalink' => get_permalink($id),
        'categories' => wp_get_post_categories($id),
        'tags' => wp_get_post_tags($id),
        'post_status' => get_post_status($id),
        'date_created' => get_post_field('post_date', $id),
      );
    }
  }

  new AnomateHelperApi();
?>