<?php
  class AnomateHelperApiAnomate extends WC_REST_Posts_Controller {
    public $namespace = 'wc/v3';
    private $api_helper;
    private $anomate;

    public function __construct() {
      $this->api_helper = new AnomateHelperApi();
      $this->anomate = new AnomateHelper();

      add_action( 'rest_api_init', array($this, 'info_route') );
      add_action( 'rest_api_init', array($this, 'token_route') );
      add_action( 'rest_api_init', array($this, 'currency_route') );
      add_action( 'rest_api_init', array($this, 'language_route') );
      add_action( 'rest_api_init', array($this, 'coupon_route') );
      add_action( 'rest_api_init', array($this, 'timezone_route') );
    }

    public function timezone_route() {
      register_rest_route( $this->namespace, '/anomate/timezone', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'timezone_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function coupon_route() {
      register_rest_route( $this->namespace, '/anomate/coupon', array(
        'methods' => WP_REST_SERVER::EDITABLE,
        'callback' => array($this, 'coupon_callback'),
        'permission_callback' => array($this->api_helper, 'update_items_permissions_check'),
      ) );
    }

    public function currency_route() {
      register_rest_route( $this->namespace, '/anomate/currency', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'currency_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function language_route() {
      register_rest_route( $this->namespace, '/anomate/language', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'language_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function token_route() {
      register_rest_route( $this->namespace, '/anomate/option', array(
        'methods' => WP_REST_SERVER::EDITABLE,
        'callback' => array($this, 'option_callback'),
        'permission_callback' => array($this->api_helper, 'update_items_permissions_check'),
      ) );
    }

    public function info_route() {
      register_rest_route( $this->namespace, '/anomate/info', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'info_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function currency_callback() {
      $response = rest_ensure_response( array(
        'currency' => get_woocommerce_currency(),
      ) );

      $response->set_status(200);

      return $response;
    }

    public function language_callback() {
      $response = rest_ensure_response( array(
        'language' => get_bloginfo('language'),
      ) );

      $response->set_status(200);

      return $response;
    }

    public function timezone_callback() {
      $response = rest_ensure_response( array(
        'timezone' => wp_timezone_string(),
      ) );

      $response->set_status(200);

      return $response;
    }

    public function coupon_callback($request) {
      if ( !isset($request['coupon']['type']) || ( !in_array( $request['coupon']['type'], array('percentage', 'fixed') ) ) ) {
        return new WP_Error( 'woocommerce_rest_anomate_invalid_data', __('Discount type is empty or invalid.', 'anomate-helper'), array(
          'status' => 400,
        ) );
      }

      if (!isset($request['coupon']['amount']) || !$request['coupon']['amount']) {
        return new WP_Error( 'woocommerce_rest_anomate_invalid_data', __('Amount is empty.', 'anomate-helper'), array(
            'status' => 400,
        ) );
      }

      $type = $request['coupon']['type'] == 'percentage' ? 'percent' : 'fixed_cart';
      
      $coupon = new WC_Coupon();
      $code = $this->get_coupon_code();

      $coupon->set_code($code);
      $coupon->set_description( __('Generated by Anomate', 'anomate-helper') );
      $coupon->set_discount_type($type);
      $coupon->set_amount($request['coupon']['amount']);

      if (isset($request['coupon']['validity']) && $request['coupon']['validity']) {
        $expire_date = new DateTime();

        $expire_date->modify('+' . $request['coupon']['validity'] . ' days');
        $coupon->set_date_expires( $expire_date->format('Y-m-d') );
      }

      if (isset($request['coupon']['minAmount']) && $request['coupon']['minAmount']) {
        $coupon->set_minimum_amount( floatval($request['coupon']['minAmount']) );
      }

      if ( isset($request['options']['productIds']) && !empty($request['options']['productIds']) ) {
        if ( !is_array($request['options']['productIds']) ) {
          return new WP_Error( 'woocommerce_rest_anomate_invalid_data', __('Product IDs should be an array.', 'anomate-helper'), array(
            'status' => 400,
          ) );
        }

        $coupon->set_product_ids($request['options']['productIds']);
      }

      $coupon->set_usage_limit(1);
      $coupon->save();

      $coupon_id = $coupon->get_id();

      if ($coupon_id) {
        update_post_meta($coupon_id, 'anomate', 1);
      }

      $response = rest_ensure_response( array(
        'code' => $code,
        'id' => $coupon_id,
      ) );

      $response->set_status(200);

      return $response;
    }

    public function get_coupon_code() {
      $chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
      $code = '';

      for ($i = 0; $i < 6; $i++) {
        $code .= $chars[wp_rand(0, strlen($chars)-1)];
      }

      return $code;
    }

    public function option_callback($request) {
      if (!isset($request['key']) || !$request['key']) {
        return new WP_Error( 'woocommerce_rest_anomate_no_key', __('key is required', 'anomate-helper'), array(
          'status' => 400,
        ) );
      }

      if ( !isset($request['value']) ) {
        return new WP_Error( 'woocommerce_rest_anomate_no_value', __('value is required', 'anomate-helper'), array(
          'status' => 400,
        ) );
      }

      $response = rest_ensure_response( array(
        'status' => update_option('anomate_' . $request['key'], $request['value']),
      ) );

      $response->set_status(200);

      return $response;
    }

    public function info_callback() {
      $response = rest_ensure_response( array(
        'version' => $this->anomate->get_version(),
      ) );
      
      $response->set_status(200);

      return $response;
    }
  }

  new AnomateHelperApiAnomate();
?>