<?php
  class AnomateHelperApiPosts extends WC_REST_Posts_Controller {
    public $namespace = 'wc/v3';
    private $api_helper;

    public function __construct() {
      $this->api_helper = new AnomateHelperApi();

      add_action( 'rest_api_init', array($this, 'posts_route') );
      add_action( 'rest_api_init', array($this, 'posts_categories_route') );
      add_action( 'rest_api_init', array($this, 'posts_tags_route') );
    }

    public function posts_route() {
      register_rest_route( $this->namespace, '/posts', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'posts_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function posts_categories_route() {
      register_rest_route( $this->namespace, '/posts/categories', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'posts_categories_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function posts_tags_route() {
      register_rest_route( $this->namespace, '/posts/tags', array(
        'methods' => WP_REST_Server::READABLE,
        'callback' => array($this, 'posts_tags_callback'),
        'permission_callback' => array($this->api_helper, 'get_items_permissions_check'),
      ) );
    }

    public function posts_categories_callback() {
      $categories = get_categories( array(
        'hide_empty' => false,
      ) );

      return rest_ensure_response($categories);
    }

    public function posts_tags_callback() {
      $tags = get_tags( array(
        'hide_empty' => false,
      ) );

      return rest_ensure_response($tags);
    }

    public function posts_callback(WP_REST_REQUEST $request) {
      $page = $request->get_param('page') ?: 1;
      $per_page = $request->get_param('per_page') ?: 100;
      
      $query = new WP_Query( array(
        'post_type' => 'post',
        'paged' => $page,
        'posts_per_page' => $per_page,
      ) );

      $posts = array();

      if ($query->have_posts()) {
        while ($query->have_posts()) {
          $query->the_post();

          $posts[] = $this->api_helper->get_post_object( get_the_ID() );
        }
      }

      wp_reset_postdata();

      $total_posts = wp_count_posts('post')->publish;
      $total_pages = ceil($total_posts / $per_page);

      $response = rest_ensure_response($posts);
      $response->header('X-WP-Total', $total_posts);
      $response->header('X-WP-TotalPages', $total_pages);

      return $response;
    }
  }

  new AnomateHelperApiPosts();
?>