<?php
  class AnomateBackInStockCampaign {
    private $anomate;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      
      add_action( 'init', array($this, 'actions') );
    }

    public function actions() {
      if ( get_option('anomate_back-in-stock') ) {
        add_action('woocommerce_simple_add_to_cart', array($this, 'single'), 31);
        add_action('woocommerce_subscription_add_to_cart', array($this, 'single'), 31);
        add_action('woocommerce_bundle_add_to_cart', array($this, 'single'), 31);
        add_action('woocommerce_woosb_add_to_cart', array($this, 'single'), 31);
        add_action('woocommerce_after_single_variation', array($this, 'variation'), 30);
        add_action( 'wp_footer', array($this, 'modal') );
        add_action( 'wp_ajax_anomate_back_in_stock_save_entry', array($this, 'save_entry') );
        add_action( 'wp_ajax_nopriv_anomate_back_in_stock_save_entry', array($this, 'save_entry') );
        add_action( 'wp_ajax_anomate_get_product_variation_attributes', array($this, 'get_product_variation_attributes') );
        add_action( 'wp_ajax_nopriv_anomate_get_product_variation_attributes', array($this, 'get_product_variation_attributes') );
      }
    }

    public function get_product_variation_attributes() {
      if ( !isset($_GET['_wpnonce']) || !wp_verify_nonce($_GET['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      $attributes_html = '';

      if (isset($_GET['id']) && $_GET['id']) {
        $product_variation = new WC_Product_Variation($_GET['id']);

        if ($product_variation) {
          $attributes = $product_variation->get_attributes();
          
          if ( !empty($attributes) ) {
            foreach ($attributes as $attribute => $value) {
              if ($value) {
                $taxonomy = get_taxonomy("pa_$attribute");

                if ($taxonomy && isset($taxonomy->labels->singular_name) && $taxonomy->labels->singular_name) {
                  $attributes_html .= '<li class="anomate-bis__product-attribute">' . $taxonomy->labels->singular_name . ': ' . $value . '</li>';
                }
              }
            }
          }
        }
      }
      
      echo wp_json_encode( array(
        'html' => $attributes_html,
      ) );

      wp_die();
    }

    public function save_entry() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }
      
      $status = false;

      if (isset($_POST['email']) && $_POST['email'] && isset($_POST['product_id']) && $_POST['product_id']) {
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/' . $_POST['action'], array(
            'body' => wp_json_encode($_POST),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $status = true;
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }

      echo wp_json_encode($status);

      wp_die();
    }

    public function modal() {
      if ( is_product() ) {
        require_once $this->anomate->get_plugin_path() . 'templates/back-in-stock/modal.php';
      }
    }

    public function variation() {
      echo '<div class="anomate-back-in-stock anomate-back-in-stock_hidden">';

	    require_once $this->anomate->get_plugin_path() . 'templates/back-in-stock/index.php';

	    echo '</div>';
    }

    public function single() {
			global $product;

			if ( !$product->is_in_stock() ) {
        echo '<div class="anomate-back-in-stock">';

				require_once $this->anomate->get_plugin_path() . 'templates/back-in-stock/index.php';

        echo '</div>';
			}
    }
  }

  new AnomateBackInStockCampaign();
?>