<?php
  class AnomateCartAbandonment {
    private $anomate;
    private $base_webhook_url;
    public $namespace = 'wc/v3';

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      
      add_action( 'init', array($this, 'actions') );
    }

    public function actions() {
      add_action( 'wp_ajax_nopriv_anomate_send_cart', array($this, 'send_cart') );
      add_action( 'wp_ajax_anomate_send_cart', array($this, 'send_cart') );

      if ( get_option('anomate_cart-abandonment') ) {
        add_action( 'wp_ajax_anomate_cart_abandonment_opt_out', array($this, 'opt_out') );
        add_action( 'wp_ajax_nopriv_anomate_cart_abandonment_opt_out', array($this, 'opt_out') );
        add_action( 'woocommerce_cart_item_removed', array($this, 'check_cart_empty_and_send') );
        add_action('wp_login', array($this, 'link_customer_existing_cart'), 10, 2);
        add_action('woocommerce_checkout_order_processed', array($this, 'checkout_order_processed'), 10, 1);
        add_action('woocommerce_payment_complete', array($this, 'set_cart_as_purchased'), 10, 1);
        add_action('woocommerce_thankyou', array($this, 'set_cart_as_purchased'), 10, 1);
        add_action( 'rest_api_init', array($this, 'api_recover_cart_route') );
        add_action('woocommerce_cart_loaded_from_session', array($this, 'maybe_apply_cart_recovery_coupon'), 11);
        add_action( 'wp_loaded', array($this, 'add_coupon_code_to_cart_session') );
        add_action( 'woocommerce_add_to_cart', array($this, 'add_coupon_code_to_cart') );
        add_filter('woocommerce_form_field_email', array($this, 'insert_newlsetter_consensus'), 10, 2);
      }
    }

    public function insert_newlsetter_consensus($field, $key) {
      if ($key == 'billing_email') {
        if ( !isset($_COOKIE['anomate_cart_abandonment_opt_out']) ) {
          $field = substr_replace( $field, '<span class="anomate-email-usage-notice" style="display: inline-block; padding-top: 10px;">' . $this->anomate->get_cart_abandonment_notice_text() . '</span>', strrpos($field, '</p>'), strlen('</p>') );
        }
      }

      return $field;
    }

    public function add_coupon_code_to_cart() {
      $coupon_code = WC()->session ? WC()->session->get('anomate_coupon') : false;

      if ( !$coupon_code || empty($coupon_code) ) {
        return;
      }

      if ( WC()->cart && !WC()->cart->has_discount($coupon_code) ) {
        WC()->cart->calculate_totals();
        WC()->cart->add_discount($coupon_code);
        WC()->session->__unset('anomate_coupon');
      }
    }

    public function add_coupon_code_to_cart_session() {
      $get = $_GET;

      if ( empty($get['coupon']) ) {
        return;
      }

      $this->check_prerequisites();

      if ( !WC()->session || ( WC()->session && !WC()->session->has_session() ) ) {
        WC()->session->set_customer_session_cookie(true);
      }

      $coupon_code = esc_attr($get['coupon']);

      WC()->session->set('anomate_coupon', $coupon_code);

      if ( WC()->cart && !WC()->cart->is_empty() && !WC()->cart->has_discount($coupon_code) ) {
        WC()->cart->calculate_totals();
        WC()->cart->add_discount($coupon_code);
        WC()->session->__unset('anomate_coupon');
      }
    }

    public function maybe_apply_cart_recovery_coupon() {
      $request = $_REQUEST;

      if ( $this->cart_is_pending_recovery() && !empty($request['coupon']) ) {
        $coupon_code = wc_clean( rawurldecode($request['coupon']) );

        if ( WC()->cart && !WC()->cart->has_discount($coupon_code) ) {
          WC()->cart->calculate_totals();
          WC()->cart->add_discount($coupon_code);
        }
      }
    }

    public function check_prerequisites() {
      if ( defined('WC_ABSPATH') ) {
        include_once WC_ABSPATH . 'includes/wc-cart-functions.php';
        include_once WC_ABSPATH . 'includes/wc-notice-functions.php';
      }

      if (null === WC()->session) {
        $session_class = apply_filters('woocommerce_session_handler', 'WC_Session_Handler');

        if ( false === strpos($session_class, '\\') ) {
          $session_class = '\\'.$session_class;
        }

        WC()->session = new $session_class();
        WC()->session->init();
      }

      if (null === WC()->customer) {
        WC()->customer = new \WC_Customer(get_current_user_id(), true);
      }

      if (null === WC()->cart) {
        WC()->cart = new \WC_Cart();

        WC()->cart->get_cart();
      }
    }

    public function return_valid_coupons($coupons) {
      $valid_coupons = array();

      if ($coupons) {
        foreach ($coupons as $coupon_code) {
          $the_coupon = new WC_Coupon($coupon_code);

          if ( !$the_coupon->is_valid() ) {
            continue;
          }

          $valid_coupons[] = $coupon_code;
        }
      }

      return $valid_coupons;
    }

    public function restore_cart($cart_token) {
      if (!$cart_token) {
        throw new Exception( esc_html__('Missing cart token', 'anomate-helper') );
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/anomate_restore_cart', array(
          'body' => wp_json_encode( array(
            'token' => $cart_token,
          ) ),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }

        $body = wp_remote_retrieve_body($response);

        if (!$body) {
          throw new Exception( __('Error getting cart from Anomate', 'anomate-helper') );
        }

        $body = json_decode($body);

        if ( isset($body->cart) && !empty($body->cart) ) {
          WC()->cart->empty_cart();
          WC()->session->set( 'cart', json_decode(wp_json_encode($body->cart), true) );
          WC()->session->set('anomate_cart_token', $cart_token);
          WC()->session->set('anomate_pending_recovery', true);

          if (isset($body->customer_id) && $body->customer_id) {
            update_user_meta($body->customer_id, '_anomate_cart_token', $cart_token);
            update_user_meta($body->customer_id, '_anomate_pending_recovery', true);
          }

          if ( isset($body->client_session) && !empty($body->client_session) ) {
            if ( isset($body->client_session->applied_coupons) && !empty($body->client_session->applied_coupons) ) {
              WC()->session->set( 'applied_coupons', $this->return_valid_coupons( (array) $body->client_session->applied_coupons ) );
            }

            if ( isset($body->client_session->chosen_shipping_methods) && !empty($body->client_session->chosen_shipping_methods) ) {
              WC()->session->set('chosen_shipping_methods', (array) $body->client_session->chosen_shipping_methods);
            }

            if ( isset($body->client_session->shipping_method_counts) && !empty($body->client_session->shipping_method_counts) ) {
              WC()->session->set('shipping_method_counts', (array) $body->client_session->shipping_method_counts);
            }

            if (isset($body->client_session->chosen_payment_method) && $body->client_session->chosen_payment_method) {
              WC()->session->set('chosen_payment_method', $body->client_session->chosen_payment_method);
            }
          }
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function recover_cart_callback($request) {
      if (isset($request['token']) && $cart_token = $request['token']) {
        $this->check_prerequisites();

        $checkout_url = wc_get_checkout_url();

        foreach ($request->get_params() as $key => $val) {
          $checkout_url = add_query_arg($key, $val, $checkout_url);
        }

        if ( !WC()->session || ( WC()->session && !WC()->session->has_session() ) ) {
          WC()->session->set_customer_session_cookie(true);
        }

        try {
          $this->restore_cart($cart_token);

          if ( isset($request['coupon']) && $coupon = rawurldecode($request['coupon']) ) {
            $checkout_url = add_query_arg(array(
              'coupon' => wc_clean($coupon),
            ), $checkout_url);
          }
        } catch (Exception $e) {
          wc_add_notice(__('Sorry, we were not able to restore your cart. Please try adding your items to your cart again.', 'anomate-helper'), 'error');
        }

        wp_safe_redirect($checkout_url);

        exit;
      }
    }

    public function api_recover_cart_route() {
      register_rest_route( $this->namespace, '/anomate/recover-cart', array(
        'methods' => 'GET',
        'callback' => array($this, 'recover_cart_callback'),
        'permission_callback' => '__return_true',
      ) );
    }

    public function mark_order_as_recovered($order_id) {
      $order = wc_get_order($order_id);

      if (!$order instanceof WC_Order) {
        return;
      }

      update_post_meta($order_id, '_anomate_cart_recovered', true);

      $order->add_order_note( __('Order cart recovered by Anomate.', 'anomate-helper') );
    }

    public function cart_is_pending_recovery($user_id = null) {
      if ( $user_id || ( $user_id = get_current_user_id() ) ) {
        return (bool) get_user_meta($user_id, '_anomate_pending_recovery', true);
      } elseif ( isset(WC()->session) ) {
        return (bool) WC()->session->anomate_pending_recovery;
      }

      return false;
    }

    public function checkout_order_processed($order_id) {
      $cart_token = $this->get_cart_token();

      if ($cart_token) {
        update_post_meta($order_id, '_anomate_cart_token', $cart_token);
      }

      if ( $this->cart_is_pending_recovery() ) {
        $this->mark_order_as_recovered($order_id);
      }
    }

    public function link_customer_existing_cart($user_login, $user) {
      $session_token = WC()->session ? WC()->session->get('anomate_cart_token') : '';

      if ($session_token && $user) {
        update_user_meta($user->ID, '_anomate_cart_token', $session_token);
      }
    }

    public function clear_user_meta($user_id) {
      delete_user_meta($user_id, '_anomate_cart_token');
      delete_user_meta($user_id, '_anomate_pending_recovery');
    }

    public function set_cart_as_purchased($order_id) {
      if (WC()->session) {
        if (isset(WC()->session->anomate_cart_token) && WC()->session->anomate_cart_token) {
          try {
            $response = wp_remote_post( $this->base_webhook_url . '/anomate_incoming_cart', array(
              'body' => wp_json_encode( array(
                'token' => WC()->session->anomate_cart_token,
                'purchased' => true, 
                'orderId' => $order_id
              ) ),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );

            unset(WC()->session->anomate_cart_token, WC()->session->anomate_pending_recovery);

            if ( $user_id = get_current_user_id() ) {
              $this->clear_user_meta($user_id);
            }

            if ( is_wp_error($response) ) {
              throw new Exception( 'WP_Error: ' . $response->get_error_message() );
            }
          } catch (Exception $e) {
            error_log( 'Error: ' . $e->getMessage() );
          }
        }
      }
    }

    public function unset_cart_token() {
      if (WC()->session) {
        if (isset(WC()->session->anomate_cart_token) && WC()->session->anomate_cart_token) {
          try {
            $response = wp_remote_post( $this->base_webhook_url . '/anomate_incoming_cart', array(
              'body' => wp_json_encode( array(
                'token' => WC()->session->anomate_cart_token,
                'cart' => [],
              ) ),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );

            unset(WC()->session->anomate_cart_token, WC()->session->anomate_pending_recovery);

            if ( $user_id = get_current_user_id() ) {
              $this->clear_user_meta($user_id);
            }

            if ( is_wp_error($response) ) {
              throw new Exception( 'WP_Error: ' . $response->get_error_message() );
            }
          } catch (Exception $e) {
            error_log( 'Error: ' . $e->getMessage() );
          }
        }
      }
    }

    public function check_cart_empty_and_send() {
      if ( WC()->cart->is_empty() ) {
        $this->unset_cart_token();

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_incoming_cart', array(
            'body' => wp_json_encode( array(
              'token' => $this->get_or_set_cart_token(),
              'cart' => [],
            ) ),
            'timeout' => 60,
          ) );
  
          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }
    }

    public function get_cart_token($user_id = false) {
      if ( $user_id || ( $user_id = get_current_user_id() ) ) {
        $token = get_user_meta($user_id, '_anomate_cart_token', true);

        if ( !$token && WC()->session && WC()->session->get('anomate_cart_token') ) {
          $token = WC()->session->get('anomate_cart_token');

          update_user_meta($user_id, '_anomate_cart_token', $token);
        }

        return $token;
      } else {
        return (WC()->session) ? WC()->session->get('anomate_cart_token') : '';
      }
    }

    public function generate_cart_token() {
      return md5( time() . wp_rand(100, 10000) );
    }

    public function set_cart_token() {
      $token = $this->generate_cart_token();

      WC()->session->set('anomate_cart_token', $token);

      if ( $user_id = get_current_user_id() ) {
        update_user_meta($user_id, '_anomate_cart_token', $token);
      }

      return $token;
    }

    public function get_or_set_cart_token() {
      if ( !$token = $this->get_cart_token() ) {
        $token = $this->set_cart_token();
      }

      return $token;
    }

    public function get_cart_total() {
      if ( is_checkout() || is_cart() || defined('WOOCOMMERCE_CHECKOUT') || defined('WOOCOMMERCE_CART') ) {
        return WC()->cart->total;
      } else {
        return WC()->cart->subtotal_ex_tax + WC()->cart->tax_total + WC()->cart->shipping_tax_total + WC()->cart->shipping_total;
      }
    }

    public function get_cart_subtotal() {
      if ( 'excl' === get_option('woocommerce_tax_display_cart') ) {
        $subtotal = WC()->cart->subtotal_ex_tax;
      } else {
        $subtotal = WC()->cart->subtotal;
      }

      return $subtotal;
    }

    public function get_client_session_data() {
      if (!WC()->session) {
        return;
      }

      return array(
        'applied_coupons' => WC()->session->get('applied_coupons'),
        'chosen_shipping_methods' => WC()->session->get('chosen_shipping_methods'),
        'shipping_method_counts' => WC()->session->get('shipping_method_counts'),
        'chosen_payment_method' => WC()->session->get('chosen_payment_method'),
      );
    }

    public function send_cart() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      if ( get_option('anomate_cart-abandonment') ) {
        $cart = WC()->cart->get_cart();
        $customer_id = get_current_user_id();
        $email = null;

        if ($customer_id) {
          $customer = new WC_Customer($customer_id);

          if ( !empty($customer) ) {
            $email = $customer->get_billing_email();
          }
        }

        if (!$email) {
          $email = isset($_POST['email']) && $_POST['email'] ? sanitize_email($_POST['email']) : null;
        }

        $name = isset($_POST['name']) && $_POST['name'] ? sanitize_text_field($_POST['name']) : null;
        $phone = isset($_POST['phone']) && $_POST['phone'] ? sanitize_text_field($_POST['phone']) : null;

        if (!$cart) {
          return;
        }
        
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_incoming_cart', array(
            'body' => wp_json_encode( array(
              'token' => $this->get_or_set_cart_token(),
              'cart' => $cart,
              'total' => (float) $this->get_cart_total(),
              'subtotal' => (float) $this->get_cart_subtotal(),
              'total_tax' => (float) (WC()->cart->tax_total + WC()->cart->shipping_tax_total),
              'total_discount' => (float) WC()->cart->discount_cart,
              'total_shipping' => (float) WC()->cart->shipping_total,
              'customer_id' => $customer_id,
              'email' => $email,
              'name' => $name,
              'phone' => $phone,
              'client_session' => $this->get_client_session_data(),
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }

      wp_die();
    }
    
    public function opt_out() {
      try {
        $response = wp_remote_post( $this->base_webhook_url . '/anomate_cart_abandonment_opt_out', array(
          'body' => wp_json_encode( array(
            'token' => $this->get_or_set_cart_token(),
          ) ),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }

      echo wp_json_encode(true);

      wp_die();
    }
  }

  new AnomateCartAbandonment();
?>