<?php
  class AnomateCustomerSurvey {
    private $anomate;
    private $base_webhook_url;
    private $plugin_path;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      $this->plugin_path = $this->anomate->get_plugin_path();

      add_action( 'init', array($this, 'create_endpoint') );
      add_action('template_redirect', array($this, 'template_redirect'), 999);
      add_action( 'wp_ajax_anomate_save_customer_survey_entry', array($this, 'save_entry') );
      add_action( 'wp_ajax_nopriv_anomate_save_customer_survey_entry', array($this, 'save_entry') );
    }

    public function save_entry() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      if (isset($_POST) && !empty($_POST) && isset($_POST['shop_campaign_id']) && $_POST['shop_campaign_id']) {
				$answers = array();

				foreach ($_POST as $key => $value) {
          if ( !in_array( $key, array('action', 'shop_campaign_id', 'acl') ) ) {
            $answers[$key] = $value;
          }
				}

        if ( empty($answers) ) {
          echo wp_json_encode(false);
        } else {
          wp_remote_post( $this->base_webhook_url . '/anomate_customer_survey_entry', array(
            'body' => wp_json_encode( array(
              'answers' => $answers,
              'campaignId' => $_POST['shop_campaign_id'],
              'acl' => $_POST['acl'],
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          echo wp_json_encode(true);
        }
			} else {
				echo wp_json_encode(false);
			}

			wp_die();
    }

    public function template_redirect() {
      global $wp_query;

      if ( isset($wp_query->query_vars['anomate_survey_id']) ) {
        $get = $_GET;

        if (!isset($get['acl']) && !$get['acl']) {
          $this->anomate->redirect404();

          exit;
        }

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_subscriber', array(
            'body' => wp_json_encode( array(
              'hash' => $get['acl'],
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $body = json_decode( wp_remote_retrieve_body($response) );
            $subscriber = isset($body->subscriber) && $body->subscriber ? $body->subscriber : null;

            $response = wp_remote_post( $this->base_webhook_url . '/anomate_customer_survey', array(
              'body' => wp_json_encode( array(
                'id' => $wp_query->query_vars['anomate_survey_id'],
                'subscriberId' => (isset($subscriber->id) && $subscriber->id) ? $subscriber->id : '',
              ) ),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );

            $tracking = new AnomateTracking();

            wp_remote_post( $this->base_webhook_url . '/anomate_track', array(
              'body' => wp_json_encode( array(
                'type' => 'opened_survey',
                'utm' => $tracking->get_utm_values(),
                'ip' => $_SERVER['REMOTE_ADDR'],
                'http_user_agent' => $_SERVER['HTTP_USER_AGENT'],
                'surveyId' => $wp_query->query_vars['anomate_survey_id'],
              ) ),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );

            if ( is_wp_error($response) ) {
              throw new Exception( 'WP_Error: ' . $response->get_error_message() );
            } else {
              $questions = json_decode( wp_remote_retrieve_body($response) );
              $already_submitted = (isset($questions->alreadySubmitted) && $questions->alreadySubmitted);

              if ( $questions && !empty($questions) ) {
                require_once $this->plugin_path . '/templates/customer-survey/index.php';
              }
            }
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
            
          $this->anomate->redirect404();
        }
          
        exit;
      }
    }

    public function create_endpoint() {
      add_filter('generate_rewrite_rules', function($wp_rewrite) {
        $wp_rewrite->rules = array_merge(array(
          'customer-survey/([^/]+)/?$' => 'index.php?anomate_survey_id=$matches[1]',
        ), $wp_rewrite->rules);
      });
    }
  }

  new AnomateCustomerSurvey();
?>