<?php
  class AnomateEmailThisProduct {
    private $anomate;
    private $base_webhook_url;
    private $plugin_path;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      $this->plugin_path = $this->anomate->get_plugin_path();
      
      add_action( 'init', array($this, 'actions') );
    }

    public function actions() {
      if ( get_option('anomate_email-this-product') ) {
        add_action('woocommerce_after_add_to_cart_button', array($this, 'display'), 31);
        add_action( 'wp_footer', array($this, 'modal') );
        add_action( 'wp_ajax_anomate_email_this_product_save_entry', array($this, 'save_entry') );
        add_action( 'wp_ajax_nopriv_anomate_email_this_product_save_entry', array($this, 'save_entry') );
      }
    }
    
    public function display() {
      require_once $this->plugin_path . 'templates/email-this-product/index.php';
    }

    public function modal() {
      if ( is_product() ) {
        require_once $this->plugin_path . 'templates/email-this-product/modal.php';
      }
    }

    public function save_entry() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }
      
      $status = false;

      if (isset($_POST['email']) && $_POST['email'] && isset($_POST['product_id']) && $_POST['product_id']) {
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/' . $_POST['action'], array(
            'body' => wp_json_encode($_POST),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $status = true;
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }

      echo wp_json_encode($status);

      wp_die();
    }
  }

  new AnomateEmailThisProduct();
?>