<?php
  class AnomateGenerateNewSubscribers {
    private $anomate;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      
      add_action( 'init', array($this, 'actions') );
    }

    public function actions() {
      add_action( 'wp_ajax_anomate_generate_new_subscriber', array($this, 'subscribe') );
      add_action( 'wp_ajax_nopriv_anomate_generate_new_subscriber', array($this, 'subscribe') );
      add_action( 'wp_ajax_anomate_save_subscriber_data', array($this, 'save_subscriber_data') );
      add_action( 'wp_ajax_nopriv_anomate_save_subscriber_data', array($this, 'save_subscriber_data') );
    }

    public function save_subscriber_data() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      $status = false;

      if (isset($_POST['first_name']) && $_POST['first_name'] && isset($_POST['last_name']) && $_POST['last_name'] && isset($_POST['subscriber_id']) && $_POST['subscriber_id']) {
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/' . $_POST['action'], array(
            'body' => wp_json_encode($_POST),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $status = true;
          }

          echo wp_json_encode( array(
            'title' => esc_html__('Thanks for subscribing!', 'anomate-helper'),
            'button' => esc_html__('Got It', 'anomate-helper'),
            'status' => $status
          ) );
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }

      wp_die();
    }

    public function get_name_title() {
      return esc_html__('What is your name?', 'anomate-helper');
    }

    public function get_name_description() {
      return esc_html__('Could we please have your name?', 'anoomate-helper');
    }

    public function get_name_form_html($button_label, $subscriber_id) {
      return '
        <input type="text" name="first_name" class="anomate-input anomate-gns-input" placeholder="' . esc_attr__('First name', 'anomate-helper') . '" required>
        <input type="text" name="last_name" class="anomate-input anomate-gns-input" placeholder=" ' . esc_attr__('Last name', 'anomate-helper') . '" required>
        <button type="submit" class="anomate-button anomate-button_fw anomate-gns-button">' . esc_attr($button_label) . '</button>
        <div class="anomate-gns-no-thanks">
          <a href="#" class="anomate-gns-no-thanks__link">' . esc_attr__('No Thanks', 'anomate-helper') . '</a>
        </div>
        <input type="hidden" name="subscriber_id" value="' . esc_attr($subscriber_id) . '">
        <input type="hidden" name="action" value="anomate_save_subscriber_data">
      ';
    }
    
    public function subscribe() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }
      
      $status = false;
      $subscriber_id = '';
      $message = '';

      if (isset($_POST['email']) && $_POST['email']) {
        try {
          $_POST['referrer_url'] = isset($_SERVER['HTTP_REFERER']) ? esc_url_raw($_SERVER['HTTP_REFERER']) : '';

          $response = wp_remote_post( $this->base_webhook_url . '/' . $_POST['action'], array(
            'body' => wp_json_encode($_POST),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $decoded_response = json_decode(wp_remote_retrieve_body($response), true);
          
            if (isset($decoded_response['status']) && $decoded_response['status'] == false && isset($decoded_response['message']) && $decoded_response['message']) {
              $message = $decoded_response['message'];
              $status = false;
            } else {
              $status = true;
              $subscriber_id = $decoded_response;
            }
            
            $subscriber_id = json_decode(wp_remote_retrieve_body($response), true);
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }

      echo wp_json_encode( array(
        'status' => $status,
        'message' => $message,
        'title' => $this->get_name_title(),
        'description' => $this->get_name_description(),
        'form' => $this->get_name_form_html( (isset($_POST['button_label']) && $_POST['button_label']) ? $_POST['button_label'] : __('Button Label', 'anomate-helper'), $subscriber_id ),
        'subscriber_id' => $subscriber_id,
      ) );

      wp_die();
    }
  }

  new AnomateGenerateNewSubscribers();
?>