<?php
  class AnomateProductReview {
    private $anomate;
    private $base_webhook_url;
    private $plugin_path;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      $this->plugin_path = $this->anomate->get_plugin_path();

      add_action( 'init', array($this, 'create_endpoint') );
      add_action('template_redirect', array($this, 'template_redirect'), 999);
      add_action( 'wp_ajax_anomate_negative_feedback', array($this, 'negative_feedback') );
      add_action( 'wp_ajax_nopriv_anomate_negative_feedback', array($this, 'negative_feedback') );
      add_action( 'wp_ajax_anomate_positive_feedback', array($this, 'positive_feedback') );
      add_action( 'wp_ajax_nopriv_anomate_positive_feedback', array($this, 'positive_feedback') );
    }

    public function positive_feedback() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      if (isset($_POST['service']) && $_POST['service'] && isset($_POST['stars']) && ($_POST['stars'] == 4 || $_POST['stars'] == 5) && isset($_POST['campaignId']) && $_POST['campaignId'] && isset($_POST['acl']) && $_POST['acl']) {
        wp_remote_post( $this->base_webhook_url . '/anomate_positive_feedback', array(
          'body' => wp_json_encode( array(
            'service' => $_POST['service'],
            'stars' => $_POST['stars'],
            'shopCampaignId' => $_POST['campaignId'],
            'acl' => $_POST['acl'],
          ) ),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        echo wp_json_encode(true);
      } else {
        echo wp_json_encode(false);
      }

      wp_die();
    }

    public function negative_feedback() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      if (isset($_POST) && !empty($_POST) && isset($_POST['shop_campaign_id']) && $_POST['shop_campaign_id']) {
				$answers = array();

				foreach ($_POST as $key => $value) {
          if ( !in_array( $key, array('action', 'shop_campaign_id', 'acl', 'gdpr', 'stars') ) ) {
            $answers[$key] = $value;
          }
				}

        if ( empty($answers) ) {
          echo wp_json_encode(false);
        } else {
          wp_remote_post( $this->base_webhook_url . '/anomate_negative_feedback', array(
            'body' => wp_json_encode( array(
              'answers' => $answers,
              'shopCampaignId' => $_POST['shop_campaign_id'],
              'acl' => $_POST['acl'],
              'stars' => $_POST['stars'],
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          echo wp_json_encode(true);
        }
			} else {
				echo wp_json_encode(false);
			}

			wp_die();
    }

    public function template_redirect() {
      global $wp_query;

      if ( isset($wp_query->query_vars['anomate_pr_id']) ) {
        $get = $_GET;

        if (!isset($get['acl']) || !$get['acl'] || !isset($get['rating']) || !$get['rating']) {
          $this->anomate->redirect404();

          exit;
        }

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_subscriber', array(
            'body' => wp_json_encode( array(
              'hash' => $get['acl'],
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $body = json_decode( wp_remote_retrieve_body($response) );
            $subscriber = isset($body->subscriber) && $body->subscriber ? $body->subscriber : null;

            $response = wp_remote_post( $this->base_webhook_url . '/anomate_product_review', array(
              'body' => wp_json_encode( array(
                'id' => $wp_query->query_vars['anomate_pr_id'],
              ) ),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );

            $tracking = new AnomateTracking();

            wp_remote_post( $this->base_webhook_url . '/anomate_track', array(
              'body' => wp_json_encode( array(
                'type' => 'opened_product_review',
                'utm' => $tracking->get_utm_values(),
                'ip' => $_SERVER['REMOTE_ADDR'],
                'http_user_agent' => $_SERVER['HTTP_USER_AGENT'],
                'surveyId' => $wp_query->query_vars['anomate_pr_id'],
              ) ),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );

            if ( is_wp_error($response) ) {
              throw new Exception( 'WP_Error: ' . $response->get_error_message() );
            } else {
              $review_builder = json_decode( wp_remote_retrieve_body($response) );

              if ( isset($review_builder->reviewService) && !empty($review_builder->reviewService) && isset($review_builder->blocks) && !empty($review_builder->blocks) ) {
                $questions = $review_builder->blocks;
                $review_services = $review_builder->reviewService;

                $reviews_map = array(
                  'trustpilot' => array(
                    'name' => __('Trustpilot', 'anomate-helper'),
                    'icon' => '
                      <svg width="280" height="81" viewBox="0 0 280 81" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M109.039 32.3264V36.6449H99.9775V60.921H94.9948V36.6449H85.9738V32.3264H109.039ZM112.313 40.2167V44.2123H112.394C112.535 43.6472 112.796 43.1024 113.177 42.5777C113.559 42.053 114.021 41.5486 114.564 41.1248C115.106 40.6808 115.709 40.3378 116.372 40.0553C117.035 39.7929 117.718 39.6517 118.401 39.6517C118.924 39.6517 119.305 39.6718 119.506 39.692C119.707 39.7122 119.908 39.7526 120.129 39.7727V44.1719C119.808 44.1114 119.486 44.071 119.145 44.0307C118.803 43.9903 118.482 43.9701 118.16 43.9701C117.397 43.9701 116.673 44.1316 115.99 44.4342C115.307 44.7369 114.724 45.2011 114.222 45.7863C113.72 46.3917 113.318 47.1181 113.017 48.0061C112.715 48.894 112.575 49.9029 112.575 51.0532V60.9009H108.034V40.2167H112.313ZM141.004 60.921H136.544V58.0354H136.463C135.901 59.0847 135.077 59.9121 133.972 60.5376C132.867 61.1632 131.742 61.4861 130.597 61.4861C127.884 61.4861 125.915 60.8201 124.71 59.4681C123.504 58.1161 122.902 56.0779 122.902 53.3537V40.2167H127.442V52.9097C127.442 54.7259 127.784 56.0174 128.487 56.764C129.17 57.5107 130.155 57.8941 131.4 57.8941C132.365 57.8941 133.148 57.7528 133.791 57.4501C134.434 57.1474 134.956 56.764 135.338 56.2595C135.74 55.7752 136.021 55.1698 136.202 54.4837C136.383 53.7976 136.463 53.051 136.463 52.2438V40.2369H141.004V60.921ZM148.739 54.2819C148.88 55.6138 149.382 56.5421 150.246 57.0869C151.13 57.6116 152.175 57.8941 153.4 57.8941C153.822 57.8941 154.304 57.8537 154.847 57.7932C155.389 57.7327 155.912 57.5914 156.374 57.4098C156.856 57.2282 157.238 56.9456 157.559 56.5824C157.86 56.2192 158.001 55.755 157.981 55.1698C157.961 54.5846 157.74 54.1003 157.338 53.7371C156.936 53.3537 156.434 53.0712 155.811 52.829C155.188 52.607 154.485 52.4052 153.681 52.2438C152.878 52.0823 152.074 51.9007 151.25 51.7191C150.407 51.5375 149.583 51.2953 148.799 51.033C148.016 50.7707 147.313 50.4074 146.69 49.9433C146.067 49.4993 145.565 48.9141 145.203 48.2078C144.821 47.5016 144.64 46.6338 144.64 45.5845C144.64 44.4544 144.922 43.5262 145.464 42.7593C146.007 41.9925 146.71 41.3871 147.534 40.923C148.377 40.4589 149.302 40.136 150.326 39.9342C151.351 39.7526 152.335 39.6517 153.26 39.6517C154.324 39.6517 155.349 39.7727 156.313 39.9947C157.278 40.2167 158.162 40.5799 158.945 41.1046C159.729 41.6091 160.372 42.275 160.894 43.0822C161.417 43.8894 161.738 44.8782 161.879 46.0284H157.137C156.916 44.9387 156.434 44.1921 155.65 43.8289C154.867 43.4454 153.963 43.2638 152.958 43.2638C152.637 43.2638 152.255 43.284 151.813 43.3445C151.371 43.4051 150.969 43.506 150.567 43.6472C150.186 43.7885 149.864 44.0105 149.583 44.293C149.322 44.5755 149.181 44.9387 149.181 45.4029C149.181 45.9679 149.382 46.4119 149.764 46.7549C150.145 47.098 150.648 47.3805 151.27 47.6226C151.893 47.8446 152.597 48.0464 153.4 48.2078C154.204 48.3693 155.028 48.5509 155.871 48.7325C156.695 48.9141 157.499 49.1563 158.302 49.4186C159.106 49.681 159.809 50.0442 160.432 50.5083C161.055 50.9725 161.557 51.5375 161.939 52.2236C162.321 52.9097 162.522 53.7774 162.522 54.7864C162.522 56.0174 162.24 57.0465 161.678 57.9143C161.115 58.7618 160.392 59.4681 159.508 59.9928C158.624 60.5174 157.619 60.921 156.534 61.1632C155.449 61.4054 154.365 61.5264 153.3 61.5264C151.994 61.5264 150.788 61.3852 149.683 61.0825C148.578 60.7798 147.614 60.3358 146.81 59.7506C146.007 59.1452 145.364 58.3986 144.902 57.5107C144.439 56.6228 144.198 55.5533 144.158 54.3223H148.739V54.2819ZM163.727 40.2167H167.163V34.0014H171.703V40.2167H175.802V43.6271H171.703V54.6855C171.703 55.1698 171.723 55.5734 171.764 55.9367C171.804 56.2797 171.904 56.5824 172.045 56.8246C172.186 57.0667 172.407 57.2483 172.708 57.3694C173.009 57.4905 173.391 57.551 173.913 57.551C174.235 57.551 174.556 57.551 174.878 57.5309C175.199 57.5107 175.521 57.4703 175.842 57.3896V60.921C175.34 60.9816 174.838 61.0219 174.375 61.0825C173.893 61.143 173.411 61.1632 172.909 61.1632C171.703 61.1632 170.739 61.0421 170.016 60.8201C169.292 60.5982 168.71 60.2551 168.308 59.8112C167.886 59.3672 167.625 58.8224 167.464 58.1564C167.323 57.4905 167.223 56.7237 167.203 55.8761V43.6674H163.767V40.2167H163.727ZM179.017 40.2167H183.316V43.0217H183.396C184.039 41.8109 184.923 40.9633 186.069 40.4387C187.214 39.914 188.439 39.6517 189.785 39.6517C191.413 39.6517 192.819 39.9342 194.025 40.5194C195.23 41.0844 196.235 41.8714 197.038 42.8804C197.842 43.8894 198.425 45.0598 198.827 46.3917C199.228 47.7235 199.429 49.1563 199.429 50.6698C199.429 52.0622 199.248 53.4142 198.887 54.7057C198.525 56.0174 197.983 57.1676 197.259 58.1766C196.536 59.1856 195.612 59.9726 194.487 60.578C193.362 61.1834 192.056 61.4861 190.529 61.4861C189.866 61.4861 189.203 61.4255 188.54 61.3045C187.877 61.1834 187.234 60.9816 186.631 60.7192C186.028 60.4569 185.446 60.1139 184.943 59.6901C184.421 59.2663 183.999 58.782 183.638 58.2371H183.557V68.5691H179.017V40.2167ZM194.889 50.5891C194.889 49.6608 194.768 48.7527 194.527 47.8648C194.286 46.9769 193.924 46.2101 193.442 45.524C192.96 44.8378 192.357 44.293 191.654 43.8894C190.931 43.4858 190.107 43.2638 189.183 43.2638C187.274 43.2638 185.827 43.9298 184.863 45.2616C183.899 46.5935 183.417 48.3693 183.417 50.5891C183.417 51.6384 183.537 52.607 183.798 53.4949C184.059 54.3828 184.421 55.1497 184.943 55.7954C185.446 56.4412 186.048 56.9456 186.752 57.3089C187.455 57.6923 188.279 57.8739 189.203 57.8739C190.248 57.8739 191.111 57.6519 191.835 57.2282C192.558 56.8044 193.141 56.2394 193.603 55.5734C194.065 54.8873 194.406 54.1205 194.607 53.2528C194.788 52.385 194.889 51.4971 194.889 50.5891ZM202.905 32.3264H207.446V36.6449H202.905V32.3264ZM202.905 40.2167H207.446V60.921H202.905V40.2167ZM211.504 32.3264H216.045V60.921H211.504V32.3264ZM229.968 61.4861C228.321 61.4861 226.854 61.2036 225.568 60.6587C224.282 60.1139 223.197 59.347 222.293 58.3986C221.409 57.43 220.726 56.2797 220.264 54.9479C219.802 53.616 219.561 52.1429 219.561 50.5487C219.561 48.9747 219.802 47.5217 220.264 46.1899C220.726 44.858 221.409 43.7078 222.293 42.7392C223.177 41.7705 224.282 41.0239 225.568 40.479C226.854 39.9342 228.321 39.6517 229.968 39.6517C231.615 39.6517 233.082 39.9342 234.368 40.479C235.654 41.0239 236.739 41.7907 237.643 42.7392C238.527 43.7078 239.21 44.858 239.672 46.1899C240.134 47.5217 240.375 48.9747 240.375 50.5487C240.375 52.1429 240.134 53.616 239.672 54.9479C239.21 56.2797 238.527 57.43 237.643 58.3986C236.759 59.3672 235.654 60.1139 234.368 60.6587C233.082 61.2036 231.615 61.4861 229.968 61.4861ZM229.968 57.8739C230.973 57.8739 231.857 57.6519 232.6 57.2282C233.343 56.8044 233.946 56.2394 234.428 55.5532C234.91 54.8671 235.252 54.0801 235.493 53.2124C235.714 52.3447 235.835 51.4568 235.835 50.5487C235.835 49.6608 235.714 48.7931 235.493 47.9052C235.272 47.0173 234.91 46.2504 234.428 45.5643C233.946 44.8782 233.343 44.3334 232.6 43.9096C231.857 43.4858 230.973 43.2638 229.968 43.2638C228.963 43.2638 228.079 43.4858 227.336 43.9096C226.593 44.3334 225.99 44.8984 225.508 45.5643C225.026 46.2504 224.684 47.0173 224.443 47.9052C224.222 48.7931 224.101 49.6608 224.101 50.5487C224.101 51.4568 224.222 52.3447 224.443 53.2124C224.664 54.0801 225.026 54.8671 225.508 55.5532C225.99 56.2394 226.593 56.8044 227.336 57.2282C228.079 57.6721 228.963 57.8739 229.968 57.8739ZM241.701 40.2167H245.137V34.0014H249.678V40.2167H253.776V43.6271H249.678V54.6855C249.678 55.1698 249.698 55.5734 249.738 55.9367C249.778 56.2797 249.878 56.5824 250.019 56.8246C250.16 57.0667 250.381 57.2483 250.682 57.3694C250.984 57.4905 251.365 57.551 251.888 57.551C252.209 57.551 252.531 57.551 252.852 57.5309C253.173 57.5107 253.495 57.4703 253.816 57.3896V60.921C253.314 60.9816 252.812 61.0219 252.35 61.0825C251.867 61.143 251.385 61.1632 250.883 61.1632C249.678 61.1632 248.713 61.0421 247.99 60.8201C247.267 60.5982 246.684 60.2551 246.282 59.8112C245.86 59.3672 245.599 58.8224 245.438 58.1564C245.298 57.4905 245.197 56.7237 245.177 55.8761V43.6674H241.742V40.2167H241.701Z" fill="#191919"/>
                        <path d="M80.6917 32.3279H59.8771L53.4479 12.4308L46.9986 32.3279L26.1841 32.3078L43.0407 44.6174L36.5914 64.4943L53.4479 52.2049L70.2844 64.4943L63.8552 44.6174L80.6917 32.3279Z" fill="#00B67A"/>
                        <path d="M65.3006 49.1194L63.8552 44.6174L53.4479 52.2049L65.3006 49.1194Z" fill="#005128"/>
                      </svg>
                    ',
                  ),
                  'feefo' => array(
                    'name' => __('Feefo', 'anomate-helper'),
                    'icon' => '
                      <svg width="280" height="81" viewBox="0 0 280 81" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M89.8042 42.1465H75.6531C76.2761 39.2095 78.9461 37.3405 82.6841 37.3405C86.1552 37.2515 88.7362 39.0315 89.8042 42.1465ZM98.7042 48.4655V47.5755C98.7042 36.1835 92.1182 29.2415 82.5951 29.2415C78.5011 29.2415 74.4961 30.9325 71.4701 34.0475C68.4441 37.0735 66.8421 40.9895 66.8421 45.2615C66.8421 49.5335 68.3551 53.4496 71.2921 56.5646C74.4071 59.8576 78.0561 61.4596 82.6841 61.4596C89.4482 61.4596 94.4322 58.2556 97.2802 51.9366H87.4902C86.1552 53.0936 84.7312 53.6276 82.8621 53.6276C78.9461 53.6276 76.7211 51.9366 75.8311 48.7325H98.6152L98.7042 48.4655ZM123.268 42.1465H109.206C109.829 39.2095 112.499 37.3405 116.237 37.3405C119.708 37.2515 122.289 39.0315 123.268 42.1465ZM132.257 48.4655V47.5755C132.257 36.1835 125.671 29.2415 116.148 29.2415C112.054 29.2415 108.049 30.9325 105.023 34.0475C101.997 37.0735 100.395 40.9895 100.395 45.2615C100.395 49.5335 101.908 53.4496 104.845 56.5646C107.96 59.8576 111.609 61.4596 116.237 61.4596C122.912 61.4596 127.985 58.2556 130.833 51.9366H121.043C119.708 53.0936 118.284 53.6276 116.415 53.6276C112.499 53.6276 110.274 51.9366 109.384 48.7325H132.168L132.257 48.4655ZM54.293 60.6586H63.0151V36.9845H66.4861V30.2205H63.0151V29.4195C63.0151 26.6604 63.6381 25.7704 66.3081 25.7704H66.4861V19.6294C65.9521 19.6294 65.5961 19.5404 65.0621 19.5404C57.675 19.5404 54.204 22.4774 54.204 28.9745C54.204 29.3305 54.293 29.6865 54.293 30.1315H51V36.8955H54.293V60.6586ZM135.639 60.6586H144.361V36.9845H147.832V30.2205H144.361V29.4195C144.361 26.6604 144.984 25.7704 147.654 25.7704H147.832V19.6294C147.298 19.6294 146.942 19.5404 146.408 19.5404C139.021 19.5404 135.55 22.4774 135.55 28.9745C135.55 29.3305 135.639 29.6865 135.639 30.1315H132.346V36.8955H135.639V60.6586ZM170.884 45.3505C170.884 49.5335 167.68 52.8266 163.764 52.8266C159.848 52.8266 156.643 49.5335 156.643 45.3505C156.643 41.1675 159.848 37.7855 163.764 37.7855C167.591 37.7855 170.884 41.1675 170.884 45.3505ZM179.606 45.1725C179.606 40.9895 177.826 36.8955 174.711 33.7805C171.685 30.8435 167.947 29.3305 163.497 29.3305C159.403 29.3305 155.397 31.0215 152.371 34.1365C149.345 37.1625 147.743 41.0785 147.743 45.3505C147.743 49.6225 149.256 53.5386 152.193 56.5646C155.308 59.8576 158.958 61.4596 163.586 61.4596C168.125 61.4596 171.952 59.7686 174.978 56.6536C178.093 53.4496 179.606 49.7115 179.606 45.1725Z" fill="#474344"/>
                        <path d="M193.311 40.1902C188.95 39.9232 185.568 36.4522 185.39 32.1802H203.991V32.0022C203.991 24.6151 199.274 19.6311 192.777 19.6311C185.924 19.6311 181.296 24.7041 181.296 31.2902C181.296 37.5202 186.102 42.9492 192.688 42.9492C197.405 42.9492 201.232 40.2792 203.279 35.3842H201.41C200.075 38.3212 197.049 40.2792 193.756 40.2792H193.311M216.985 40.1902C221.346 39.9232 224.728 36.4522 224.906 32.1802H206.305V32.0022C206.305 24.6151 211.022 19.6311 217.519 19.6311C224.372 19.6311 229 24.7041 229 31.2902C229 37.5202 224.194 42.9492 217.608 42.9492C212.891 42.9492 209.064 40.2792 207.017 35.3842H208.886C210.221 38.3212 213.247 40.2792 216.451 40.2792H216.985" fill="#FDDC47"/>
                      </svg>
                    ',
                  ),
                  'facebook' => array(
                    'name' => __('Facebook', 'anomate-helper'),
                    'icon' => '
                      <svg width="280" height="81" viewBox="0 0 280 81" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M32.1453 63.7207H22.8379V40.4642H16.4976V32.8924H22.8377V27.5045C22.8377 21.1198 25.6419 16.5408 34.9241 16.5408C36.8873 16.5408 39.9695 16.9374 39.9695 16.9374V23.9683H36.7322C33.4337 23.9683 32.1458 24.9739 32.1458 27.7543V32.8924H39.846L39.1603 40.4642H32.1456L32.1453 63.7207ZM53.5014 32.2873C53.3658 32.2873 53.2262 32.2922 53.0882 32.2957C44.4578 32.2957 40.5092 38.8027 40.5092 48.0395C40.5092 59.6754 45.6311 64.3324 53.1556 64.3324C57.4607 64.3324 60.2891 62.5162 62.0083 59.1268V63.7239H70.8609V32.8956H62.0083V37.6366C60.6045 34.5863 57.697 32.3234 53.5014 32.2873ZM55.7524 39.5719C59.3772 39.5719 61.5528 42.1062 61.5528 46.4168L61.5612 50.8196C61.5612 53.725 59.7642 57.1241 55.7524 57.1241C49.5846 57.1241 49.7494 50.4487 49.7494 48.2254C49.7494 40.7467 53.0356 39.5719 55.7524 39.5719ZM74.4361 48.3113C74.4361 44.5652 74.2573 32.3073 90.1901 32.3073C96.5858 32.3073 99.2564 34.3457 99.2564 34.3457L97.1099 41.0188C97.1099 41.0188 94.4428 39.5467 90.9674 39.5467C86.5161 39.5467 83.6758 42.1332 83.6758 46.684L83.6807 49.9471C83.6807 54.3199 86.4213 57.2389 90.9765 57.2389C94.1427 57.2389 97.0608 55.7529 97.0608 55.7529L99.2018 62.2867C99.2018 62.2867 96.7599 64.3379 90.2348 64.3379C75.0642 64.3379 74.4363 53.3403 74.4363 48.3113H74.4361ZM151.163 32.2957C159.793 32.2957 163.804 38.8027 163.804 48.0395C163.804 59.6754 158.682 64.3324 151.158 64.3324C146.853 64.3324 143.67 62.5164 141.951 59.1268V63.7239L133.21 63.7204V17.4781L142.491 16.6668V37.2189C143.83 33.6232 148.232 32.2957 151.163 32.2957ZM148.561 39.5719C144.936 39.5719 142.491 42.1062 142.491 46.4168L142.482 50.8196C142.477 53.725 144.176 57.1241 148.561 57.1241C154.729 57.1241 154.564 50.4487 154.564 48.2254C154.564 40.7467 151.278 39.5719 148.561 39.5719ZM115.36 32.3212C105.571 32.3212 100.403 37.6707 100.403 47.1774V48.9437C100.403 61.2825 107.66 64.4592 116.312 64.4592C124.722 64.4592 128.529 62.1015 128.529 62.1015L126.792 55.8228C126.792 55.8228 122.314 57.7324 117.425 57.7324C112.357 57.7324 110.177 56.4375 109.618 51.5552H129.271V46.5181C129.271 36.2058 123.471 32.321 115.359 32.321L115.36 32.3212ZM115.596 38.6083C118.984 38.6083 121.18 40.691 121.059 45.5211H109.635C109.833 40.4375 112.201 38.6083 115.596 38.6083ZM182.31 32.2789C172.258 32.2789 166.966 37.9569 166.966 48.1323C166.966 62.0935 176.088 64.3409 182.327 64.3409C191.46 64.3409 197.537 59.4122 197.537 48.2591C197.537 36.6507 190.704 32.2789 182.31 32.2789ZM182.184 39.5972C186.604 39.5972 188.355 42.9131 188.355 46.6875V49.9325C188.355 54.5049 185.905 57.1496 182.167 57.1496C178.671 57.1496 176.215 54.6757 176.215 49.9325V46.6875C176.215 41.6288 179.138 39.5972 182.184 39.5972ZM216.026 32.2789C205.974 32.2789 200.681 37.9569 200.681 48.1323C200.681 62.0935 209.804 64.3409 216.043 64.3409C225.176 64.3409 231.252 59.4122 231.252 48.2591C231.252 36.6507 224.42 32.2789 216.026 32.2789ZM215.899 39.5972C220.32 39.5972 222.071 42.9131 222.071 46.6875V49.9325C222.071 54.5049 219.62 57.1496 215.883 57.1496C212.387 57.1496 209.93 54.6757 209.93 49.9325V46.6875C209.93 41.6288 212.854 39.5972 215.899 39.5972ZM234.759 63.7207V17.4781L244.067 16.6668V47.6614L253.302 32.8924H263.132L253.499 48.1888L263.503 63.7207H253.645L244.067 48.6394V63.7207H234.759Z" fill="#1877F2"/>
                      </svg>
                    ',
                  ),
                  'review' => array(
                    'name' => __('Reviews.io', 'anomate-helper'),
                    'icon' => '
                      <svg width="282" height="81" viewBox="0 0 282 81" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M73.0444 52.8737L65.7558 43.4913C70.4355 42.3957 73.7072 39.3408 73.7072 34.2774V34.1909C73.7072 31.6511 72.7785 29.3915 71.2097 27.8212C69.205 25.8165 66.0659 24.6171 62.1491 24.6171H50.5865C49.4505 24.6171 48.4715 25.5861 48.4715 26.7758V54.3598C48.4715 55.5498 49.4505 56.5189 50.5865 56.5189C51.7716 56.5189 52.7437 55.5472 52.7437 54.3598V44.2935H61.0271L69.6039 55.4358C70.0748 56.0638 70.7108 56.5189 71.5485 56.5189C72.6301 56.5189 73.7072 55.54 73.7072 54.4021C73.7072 53.825 73.4613 53.3439 73.0444 52.8737ZM69.3909 34.3231L69.3912 34.4111C69.3912 38.167 66.2218 40.3737 61.839 40.3737H52.7437V28.6249H61.8832C66.5942 28.6249 69.3909 30.7371 69.3909 34.3231Z" fill="black"/>
                        <path d="M79.9333 54.1396C79.9333 55.3277 80.9122 56.2972 82.0482 56.2972H101.467C102.568 56.2972 103.448 55.4157 103.448 54.3145C103.448 53.2147 102.568 52.3332 101.467 52.3332H84.2059V42.3062H99.2604C100.362 42.3062 101.243 41.4262 101.243 40.325C101.243 39.2784 100.362 38.3422 99.2604 38.3422H84.2059V28.5826H101.247C102.346 28.5826 103.229 27.7011 103.229 26.5998C103.229 25.4985 102.346 24.6171 101.247 24.6171H82.0482C80.9126 24.6171 79.9333 25.5861 79.9333 26.7762V54.1396Z" fill="black"/>
                        <path d="M121.411 56.6523L121.643 56.6515C122.799 56.6315 123.519 55.9804 123.976 54.9626L135.944 27.3197C136.05 27.0538 136.104 26.7879 136.104 26.4688C136.104 25.3815 135.185 24.3977 133.989 24.3977C133.042 24.3977 132.286 25.113 131.916 25.8498C131.912 25.8581 131.908 25.8664 131.904 25.8751L121.545 50.6897L111.226 25.9631C110.859 25.068 110.109 24.3977 109.055 24.3977C107.863 24.3977 106.895 25.4313 106.895 26.5111C106.895 26.8884 106.952 27.1565 107.112 27.4775L119.019 54.9543C119.434 55.9891 120.22 56.6523 121.411 56.6523Z" fill="black"/>
                        <path d="M141.758 26.5564V54.3606C141.758 55.5506 142.737 56.5197 143.873 56.5197C145.058 56.5197 146.031 55.548 146.031 54.3606V26.5564C146.031 25.369 145.058 24.3977 143.873 24.3977C142.737 24.3977 141.758 25.3664 141.758 26.5564Z" fill="black"/>
                        <path d="M175.214 24.6178L175.163 24.6171H155.964C154.829 24.6171 153.85 25.5861 153.85 26.7762V54.1396C153.85 55.3277 154.829 56.2972 155.964 56.2972H175.383C176.483 56.2972 177.364 55.4157 177.364 54.3145C177.364 53.2147 176.483 52.3332 175.383 52.3332H158.122V42.3062H173.175C174.279 42.3062 175.158 41.4262 175.158 40.325C175.158 39.2784 174.279 38.3422 173.175 38.3422H158.122V28.5826H175.163C176.262 28.5826 177.146 27.7011 177.146 26.5998C177.146 25.5159 176.29 24.6446 175.214 24.6178Z" fill="black"/>
                        <path d="M213.061 56.6958H213.423C214.453 56.6739 215.193 55.9684 215.555 54.9313C215.554 54.9347 225.441 27.4848 225.441 27.4848C225.442 27.481 225.443 27.4776 225.445 27.4739C225.543 27.1717 225.685 26.8148 225.685 26.5127C225.685 25.4307 224.661 24.3993 223.525 24.3993C222.509 24.3993 221.797 25.0723 221.475 26.0353C221.476 26.0312 213.297 49.5579 213.297 49.5579L205.583 26.0361C205.264 25.0753 204.556 24.3993 203.49 24.3993V24.4027L203.268 24.3993C202.148 24.3993 201.493 25.0753 201.174 26.0361L193.461 49.5571L185.325 26.1177C185.01 25.1724 184.201 24.3993 183.143 24.3993C181.959 24.3993 180.942 25.4258 180.942 26.5569C180.942 26.8639 181.035 27.1706 181.137 27.4758L191.026 54.9321C191.389 56.019 192.13 56.6754 193.158 56.6958H193.52C194.548 56.6739 195.29 55.968 195.651 54.9306L203.269 32.2895L210.93 54.9313C211.292 55.9684 212.035 56.6739 213.061 56.6958Z" fill="black"/>
                        <path d="M247.977 47.8722V47.9602C247.977 50.8112 245.37 52.8196 241.486 52.8196C237.669 52.8196 234.835 51.6629 232.005 49.2647L231.997 49.2575C231.717 48.9841 231.223 48.7578 230.674 48.7578C229.532 48.7578 228.601 49.6775 228.601 50.8728C228.601 51.5813 228.935 52.1795 229.422 52.5137C232.934 55.3005 236.762 56.7394 241.354 56.7394C247.735 56.7394 252.293 53.1169 252.293 47.6078V47.518C252.293 42.6234 249.058 39.9529 241.922 38.3969C235.439 37.0071 233.846 35.5577 233.846 32.778V32.69C233.846 30.0947 236.281 28.0965 240.028 28.0965C242.814 28.0965 245.257 28.8707 247.786 30.7133L247.788 30.7152C248.165 30.9856 248.544 31.0974 249.033 31.0974C250.175 31.0974 251.102 30.1729 251.102 29.0267C251.102 28.2204 250.626 27.6248 250.194 27.3004L250.188 27.2955C247.297 25.2179 244.273 24.1767 240.117 24.1767C234 24.1767 229.572 27.9413 229.572 32.9997L229.965 33.3932L229.572 33.0024V33.0843L229.965 33.4797L229.572 33.0866C229.572 38.3433 232.896 40.7883 240.255 42.387L240.257 42.3874C246.432 43.6907 247.977 45.1413 247.977 47.8722Z" fill="black"/>
                        <path d="M257.156 52.1749L257.119 52.1746C256.289 52.1746 255.698 52.769 255.698 53.5704V54.0644C255.698 54.8647 256.29 55.4856 257.119 55.4856C257.918 55.4856 258.515 54.8662 258.515 54.0644C258.515 54.1951 258.409 54.3005 258.278 54.3005C258.278 54.3005 258.515 54.274 258.515 54.0535V53.5704C258.515 52.78 257.938 52.1931 257.156 52.1749ZM255.954 54.2971C255.941 54.2997 255.934 54.3005 255.934 54.3005C255.941 54.3005 255.948 54.3005 255.955 54.2997L255.954 54.2971Z" fill="black"/>
                        <path d="M262.191 43.2048V54.2878C262.191 54.9638 262.714 55.4869 263.388 55.4869C264.068 55.4869 264.564 54.9653 264.564 54.2878V43.2048C264.564 42.5269 264.041 42.0057 263.365 42.0057C262.719 42.0057 262.191 42.5586 262.191 43.2048ZM262.018 38.6872C262.018 39.4119 262.611 39.935 263.365 39.935C264.148 39.935 264.735 39.4104 264.735 38.6872V38.3676C264.735 37.6134 264.148 37.118 263.365 37.118C262.611 37.118 262.018 37.6119 262.018 38.3676L262.018 38.6872Z" fill="black"/>
                        <path fill-rule="evenodd" clip-rule="evenodd" d="M281.5 48.764L281.5 48.7104C281.5 44.9767 278.587 41.8572 274.625 41.8572C270.638 41.8572 267.723 45.0281 267.723 48.7591V48.8082C267.723 52.5403 270.613 55.6594 274.575 55.6594C278.561 55.6594 281.498 52.4927 281.5 48.764ZM279.078 48.8082V48.7591C279.078 46.1524 277.135 44.0069 274.575 44.0069C271.945 44.0069 270.145 46.1517 270.145 48.7104V48.7591C270.145 51.3653 272.065 53.4833 274.625 53.4833C277.252 53.4833 279.078 51.3665 279.078 48.8082Z" fill="black"/>
                        <path fill-rule="evenodd" clip-rule="evenodd" d="M35.6234 27.0565L33.726 28.0082C37.4249 30.9952 39.2332 34.8534 39.5693 39.5221C39.2883 48.5336 35.0365 54.3255 27.7329 56.8094C19.2947 59.3519 13.9477 57.2947 8.77364 52.0229L8.44771 54.0494L10.5513 56.2414C17.8686 63.8669 30.0004 64.1172 37.6258 56.8C45.2513 49.4823 45.5017 37.3509 38.184 29.7251L35.6234 27.0565Z" fill="#FEEF7C"/>
                        <path fill-rule="evenodd" clip-rule="evenodd" d="M7.40831 52.9211L8.67953 51.8107C3.39787 44.3261 3.17656 33.3685 10.4047 27.3361C15.7627 22.8645 26.394 20.5468 34.8994 28.0355L35.5342 26.9188L33.4616 24.7585C26.1439 17.1331 14.0126 16.8827 6.38672 24.2003C-1.23874 31.5176 -1.48875 43.6494 5.82853 51.2748L7.40831 52.9211Z" fill="#5CD3CB"/>
                        <path d="M2.83784 40.5535C2.83784 51.1485 11.4282 59.7389 22.0233 59.7389C32.6202 59.7389 41.2102 51.1485 41.2102 40.5535C41.2102 29.9565 32.6202 21.3661 22.0233 21.3661C11.4282 21.3661 2.83784 29.9565 2.83784 40.5535ZM16.1917 44.0235C16.3934 43.3852 16.1691 42.6896 15.6328 42.2889C14.2128 41.2284 11.4131 39.1376 9.53197 37.7327C9.26043 37.5299 9.1494 37.176 9.25628 36.8542C9.36316 36.5325 9.66378 36.3157 10.0029 36.3157H17.2941C17.9728 36.3157 18.5748 35.8806 18.7882 35.2367C19.363 33.5006 20.5054 30.0502 21.263 27.7631C21.3695 27.4417 21.6698 27.2241 22.0086 27.2237C22.3473 27.2234 22.6487 27.4398 22.756 27.7608C23.5215 30.0498 24.6775 33.5058 25.258 35.2412C25.4729 35.8829 26.0738 36.3157 26.7505 36.3157C28.4753 36.3157 31.798 36.3157 34.0603 36.3157C34.3983 36.3157 34.6989 36.5317 34.8062 36.8527C34.9134 37.1737 34.8039 37.5272 34.5335 37.7308C32.658 39.1436 29.8568 41.2533 28.4398 42.3206C27.9066 42.722 27.6849 43.4166 27.8862 44.0526C28.4342 45.783 29.5332 49.2534 30.2757 51.5976C30.3791 51.925 30.2583 52.2823 29.9769 52.4794C29.6956 52.6766 29.319 52.6686 29.0464 52.4594C27.1622 51.0129 24.4094 48.8999 22.9678 47.7937C22.4009 47.3586 21.6124 47.3598 21.047 47.7971C19.6194 48.9007 16.904 51.0005 15.0357 52.445C14.7638 52.6554 14.3865 52.6649 14.1044 52.4677C13.8223 52.2709 13.7007 51.9137 13.8041 51.5859C14.5466 49.2349 15.6441 45.7585 16.1917 44.0235Z" fill="black"/>
                      </svg>
                    ',
                  ),
                  'yotpo' => array(
                    'name' => __('Yotpo', 'anomate-helper'),
                    'icon' => '
                      <svg width="280" height="81" viewBox="0 0 280 81" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path fill-rule="evenodd" clip-rule="evenodd" d="M62.3079 27.3108L68.7527 45.08L75.5055 27.3108H85.0914L68.6996 68.4592H59.2185L64.0669 55.7088L52.4141 27.3108H62.3079ZM163.556 26.6807C172.212 26.6807 178.524 33.3975 178.524 42.5909C178.524 51.7844 172.212 58.5028 163.556 58.5028C160.362 58.5028 157.673 57.6569 155.62 56.0262L155.487 55.9183L155.373 55.8245V68.4498H146.135V27.3108H154.303V30.3862L154.35 30.333C156.362 28.0378 159.407 26.7682 163.168 26.6854L163.367 26.6822L163.556 26.6807ZM101.916 26.6807C111.447 26.6807 118.203 33.2662 118.203 42.5909C118.203 51.8766 111.426 58.5028 101.916 58.5028C92.3539 58.5028 85.5651 51.886 85.5651 42.5909C85.5651 33.2568 92.3305 26.6807 101.916 26.6807ZM133.593 20.5408V27.3108H141.192V35.2894H133.593V46.3027C133.593 48.7668 134.789 50.1224 136.969 50.2052L137.075 50.2068L137.183 50.2084C138.66 50.2084 139.78 49.8206 140.782 48.8575L140.876 48.7652L141.124 48.5104H141.193V57.3114L140.91 57.4474C139.389 58.1744 138.452 58.5028 135.86 58.5028C128.537 58.5028 124.515 54.5158 124.359 47.0704L124.356 46.8437V46.617L124.354 35.2894H121.011V27.3108H124.606V20.5408H133.593ZM198.708 26.6807C208.24 26.6807 214.996 33.2662 214.996 42.5909C214.996 51.8766 208.218 58.5028 198.708 58.5028C189.146 58.5028 182.357 51.886 182.357 42.5909C182.357 33.2568 189.124 26.6807 198.708 26.6807ZM222.525 48.3791C225.321 48.3791 227.587 50.6461 227.587 53.4401C227.587 56.2357 225.319 58.5028 222.525 58.5028C219.73 58.5028 217.464 56.2357 217.464 53.4401C217.464 50.6446 219.731 48.3791 222.525 48.3791ZM162.172 34.9751C158.01 34.9751 155.184 38.0552 155.184 42.5909C155.184 47.1282 158.01 50.2084 162.172 50.2084C166.388 50.2084 169.224 47.1376 169.224 42.5909C169.224 38.0458 166.388 34.9751 162.172 34.9751ZM101.915 34.9751C97.7402 34.9751 94.8649 38.0708 94.8649 42.5909C94.8649 47.1126 97.7402 50.2084 101.916 50.2084C106.038 50.2084 108.905 47.1032 108.905 42.5909C108.905 38.0802 106.036 34.9751 101.915 34.9751ZM198.708 34.9751C194.534 34.9751 191.657 38.0708 191.657 42.5909C191.657 47.1126 194.534 50.2084 198.708 50.2084C202.83 50.2084 205.697 47.1032 205.697 42.5909C205.697 38.0802 202.83 34.9751 198.708 34.9751Z" fill="#0042E4"/>
                      </svg>
                    ',
                  ),
                  'googleBusiness' => array(
                    'name' => __('Google', 'anomate-helper'),
                    'icon' => '
                      <svg width="280" height="81" viewBox="0 0 280 81" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M67.6427 35.8413V42.3009H83.2317C82.8179 45.8744 81.5763 48.6232 79.6449 50.4099C77.4376 52.6089 73.8507 55.0828 67.6427 55.0828C58.1238 55.0828 50.6742 47.3862 50.6742 37.9029C50.6742 28.4196 57.9858 20.723 67.6427 20.723C72.7471 20.723 76.6099 22.7845 79.369 25.3959L83.9215 20.8604C80.0587 17.1495 74.8164 14.2633 67.6427 14.2633C54.5369 14.2633 43.5005 24.8461 43.5005 37.9029C43.5005 50.9596 54.5369 61.5425 67.6427 61.5425C74.6785 61.5425 80.0587 59.206 84.1974 54.9454C88.474 50.6847 89.8536 44.6374 89.8536 39.827C89.8536 38.3152 89.7156 36.9408 89.5777 35.8413H67.6427Z" fill="#4285F4"/>
                        <path d="M109.168 30.4812C100.752 30.4812 93.7166 36.9408 93.7166 45.7369C93.7166 54.5331 100.614 60.9927 109.168 60.9927C117.721 60.9927 124.619 54.6705 124.619 45.8744C124.619 36.9408 117.721 30.4812 109.168 30.4812ZM109.168 55.0828C104.477 55.0828 100.476 51.2345 100.476 45.8744C100.476 40.3768 104.477 36.6659 109.168 36.6659C113.858 36.6659 117.859 40.3768 117.859 45.8744C117.859 51.2345 113.858 55.0828 109.168 55.0828Z" fill="#EA4335"/>
                        <path d="M184.353 33.9171C182.836 32.1304 179.939 30.4812 176.214 30.4812C168.488 30.4812 161.866 37.0783 161.866 45.7369C161.866 54.2582 168.488 60.9927 176.214 60.9927C179.939 60.9927 182.836 59.3434 184.353 57.5567H184.629V59.7558C184.629 65.5282 181.456 68.6893 176.49 68.6893C172.351 68.6893 169.868 65.8031 168.764 63.1917L162.97 65.6656C164.625 69.6514 169.178 74.7366 176.628 74.7366C184.491 74.7366 191.251 70.0637 191.251 58.7937V31.3058H184.905V33.9171H184.353ZM176.904 55.0828C172.213 55.0828 168.764 51.0971 168.764 45.8744C168.764 40.5142 172.351 36.6659 176.904 36.6659C181.456 36.6659 185.043 40.6517 185.043 46.0118C185.181 51.2345 181.594 55.0828 176.904 55.0828Z" fill="#4285F4"/>
                        <path d="M143.518 30.4812C135.103 30.4812 128.067 36.9408 128.067 45.7369C128.067 54.5331 134.965 60.9927 143.518 60.9927C152.072 60.9927 158.969 54.6705 158.969 45.8744C158.969 36.9408 152.072 30.4812 143.518 30.4812ZM143.518 55.0828C138.828 55.0828 134.827 51.2345 134.827 45.8744C134.827 40.3768 138.828 36.6659 143.518 36.6659C148.209 36.6659 152.21 40.3768 152.21 45.8744C152.21 51.2345 148.209 55.0828 143.518 55.0828Z" fill="#FBBC05"/>
                        <path d="M196.355 14.9505H202.977V61.1301H196.355V14.9505Z" fill="#34A853"/>
                        <path d="M223.394 55.0828C219.945 55.0828 217.6 53.571 215.944 50.4099L236.5 42.0261L235.81 40.2394C234.568 36.8034 230.568 30.4812 222.704 30.4812C214.841 30.4812 208.219 36.6659 208.219 45.7369C208.219 54.2582 214.703 60.9927 223.394 60.9927C230.43 60.9927 234.43 56.7321 236.224 54.2582L230.981 50.8222C229.188 53.4335 226.843 55.0828 223.394 55.0828ZM222.98 36.2536C225.739 36.2536 228.084 37.628 228.774 39.5522L214.979 45.3246C214.841 39.0024 219.531 36.2536 222.98 36.2536Z" fill="#EA4335"/>
                      </svg>
                    ',
                  ),
                );

                require_once $this->plugin_path . '/templates/product-review/index.php';
              }
            }
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
            
          $this->anomate->redirect404();
        }
          
        exit;
      }
    }

    public function create_endpoint() {
      add_filter('generate_rewrite_rules', function($wp_rewrite) {
        $wp_rewrite->rules = array_merge(array(
          'product-review/([^/]+)/?$' => 'index.php?anomate_pr_id=$matches[1]',
        ), $wp_rewrite->rules);
      });
    }
  }

  new AnomateProductReview();
?>