<?php
  class AnomateRaffleGiveaway {
    private $anomate;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();

      add_action( 'init', array($this, 'create_endpoint') );
      add_action('template_redirect', array($this, 'template_redirect'), 999);
      add_action( 'wp_ajax_anomate_raffle_giveaway_entry', array($this, 'save_entry') );
      add_action( 'wp_ajax_nopriv_anomate_raffle_giveaway_entry', array($this, 'save_entry') );
    }

    public function save_entry() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      $status = false;
      $subscriber_id = '';
      $message = '';
      $generate_new_subscribers = new AnomateGenerateNewSubscribers();

      if (isset($_POST) && !empty($_POST) && isset($_POST['shop_campaign_id']) && $_POST['shop_campaign_id']) {
        $response = wp_remote_post( $this->base_webhook_url . '/' . $_POST['action'], array(
          'body' => wp_json_encode($_POST),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        } else {
          $decoded_response = json_decode(wp_remote_retrieve_body($response), true);
          
          if (isset($decoded_response['subscriberId']) && $decoded_response['subscriberId']) {
            $status = true;
            $subscriber_id = $decoded_response['subscriberId'];
          } else if (isset($decoded_response['status']) && $decoded_response['status'] == false && isset($decoded_response['message']) && $decoded_response['message']) {
            $message = $decoded_response['message'];
          }
        }
			}

      echo wp_json_encode( array(
        'status' => $status,
        'title' => $generate_new_subscribers->get_name_title(),
        'description' => $generate_new_subscribers->get_name_description(),
        'form' => $generate_new_subscribers->get_name_form_html( (isset($_POST['button_label']) && $_POST['button_label']) ? $_POST['button_label'] : __('Button Label', 'anomate-helper'), $subscriber_id ),
        'subscriber_id' => $decoded_response,
        'message' => $message,
        'shop_campaign_id' => $_POST['shop_campaign_id'],
      ) );

			wp_die();
    }

    public function template_redirect() {
      global $wp_query;

      if ( isset($wp_query->query_vars['anomate_giveaway_id']) ) {
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_raffle_giveaway', array(
            'body' => wp_json_encode( array(
              'id' => $wp_query->query_vars['anomate_giveaway_id'],
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $data = json_decode( wp_remote_retrieve_body($response) );

            if ( $data && !empty($data) ) {
              $product = null;

              if (isset($data->raffleSetup->prizeType->raffleType) && $data->raffleSetup->prizeType->raffleType == 'catalog' && isset($data->raffleSetup->prizeType->product->originalId) && $data->raffleSetup->prizeType->product->originalId) {
                $product = wc_get_product($data->raffleSetup->prizeType->product->originalId);
              }

              $raffle_data = array();
              $subscriber_id = '';
              $subscriber_data = null;
              $just_confirmed = false;

              if (isset($_GET['confirm']) && $_GET['confirm']) {
                $response = wp_remote_post( $this->base_webhook_url . '/anomate_raffle_giveaway_confirm', array(
                  'body' => wp_json_encode( array(
                    'acl' => $_GET['acl'],
                    'shopCampaignId' => $wp_query->query_vars['anomate_giveaway_id'],
                  ) ),
                  'headers' => array(
                    'Content-Type' => 'application/json',
                  ),
                  'timeout' => 60,
                ) );

                if ( is_wp_error($response) ) {
                  throw new Exception( 'WP_Error: ' . $response->get_error_message() );
                } else {
                  $raffle_data = array( array(
                    'subscriberId' => json_decode( wp_remote_retrieve_body($response) ),
                    'shopCampaignId' => $wp_query->query_vars['anomate_giveaway_id'],
                  ) );

                  $just_confirmed = true;
                }
              }
              
              if (isset($_GET['acl']) && $_GET['acl']) {
                $response = wp_remote_post( $this->base_webhook_url . '/anomate_raffle_giveaway_entry_by_acl', array(
                  'body' => wp_json_encode( array(
                    'acl' => $_GET['acl'],
                    'shopCampaignId' => $wp_query->query_vars['anomate_giveaway_id'],
                  ) ),
                  'headers' => array(
                    'Content-Type' => 'application/json',
                  ),
                  'timeout' => 60,
                ) );

                if ( is_wp_error($response) ) {
                  throw new Exception( 'WP_Error: ' . $response->get_error_message() );
                } else {
                  $raffle_data = array( array(
                    'subscriberId' => json_decode( wp_remote_retrieve_body($response) ),
                    'shopCampaignId' => $wp_query->query_vars['anomate_giveaway_id'],
                  ) );
                }
              } else {
                $raffle_data = (isset($_COOKIE['raffleData']) && $_COOKIE['raffleData']) ? json_decode(str_replace('\\', '', $_COOKIE['raffleData']), true) : '';
              }
              
              if ( !empty($raffle_data) ) {
                foreach ($raffle_data as $item) {
                  if (isset($item['shopCampaignId']) && $item['shopCampaignId'] == $wp_query->query_vars['anomate_giveaway_id'] && isset($item['subscriberId']) && $item['subscriberId']) {
                    $subscriber_id = $item['subscriberId'];
                  }
                }
              }

              if ($subscriber_id) {
                $response = wp_remote_post( $this->base_webhook_url . '/anomate_raffle_giveaway_subscriber', array(
                  'body' => wp_json_encode( array(
                    'id' => $wp_query->query_vars['anomate_giveaway_id'],
                    'subscriberId' => $subscriber_id,
                  ) ),
                  'headers' => array(
                    'Content-Type' => 'application/json',
                  ),
                  'timeout' => 60,
                ) );

                if ( is_wp_error($response) ) {
                  throw new Exception( 'WP_Error: ' . $response->get_error_message() );
                } else {
                  $subscriber_data = json_decode( wp_remote_retrieve_body($response) );
                }
              }

              if (isset($_GET['ref']) && $_GET['ref']) {
                setcookie('raffleRef', wp_json_encode( array( array(
                  'shopCampaignId' => $wp_query->query_vars['anomate_giveaway_id'],
                  'ref' => sanitize_text_field($_GET['ref']),
                ) ) ), time() + 86400, COOKIEPATH, COOKIE_DOMAIN, is_ssl(), true);
              }

              $template_dir = $this->anomate->get_plugin_path() . 'templates/raffle-giveaway/';

              require_once $template_dir . 'index.php';
            }
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
            
          $this->anomate->redirect404();
        }
          
        exit;
      }
    }

    public function create_endpoint() {
      add_filter('generate_rewrite_rules', function($wp_rewrite) {
        $wp_rewrite->rules = array_merge(array(
          'raffle-giveaway/([^/]+)/?$' => 'index.php?anomate_giveaway_id=$matches[1]',
        ), $wp_rewrite->rules);
      });
    }
  }

  new AnomateRaffleGiveaway();
?>