<?php
  class AnomateCheckout {
    private $anomate;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();

      add_action('woocommerce_after_order_notes', array($this, 'marketing_checkbox'), 10, 1);
      add_action( 'woocommerce_checkout_update_order_meta', array($this, 'marketing_checkbox_process') );
      add_action( 'woocommerce_blocks_loaded', array($this, 'marketing_checkbox_blocks') );
      add_action('woocommerce_thankyou', array($this, 'save_subscriber'), 10, 1);
    }

    public function save_subscriber($order_id) {
      if (!$order_id) {
        return;
      }

      $order = wc_get_order( absint($order_id) );

      if (!$order) {
        return;
      }

      $additional_fields = $order->get_meta('_additional_fields', true);
      
      if ( !( (is_array($additional_fields) && isset($additional_fields['anomate/marketing']) && $additional_fields['anomate/marketing']) || get_post_meta($order_id, 'anomate_marketing', true) ) ) {
        return;
      }
      
      try {
        $response = wp_remote_post( $this->base_webhook_url . '/anomate_create_subscriber', array(
          'body' => wp_json_encode( array(
            'email' => $order->get_billing_email(),
            'firstName' => $order->get_billing_first_name(),
            'lastName' => $order->get_billing_last_name(),
          ) ),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function marketing_checkbox_blocks() {
      if ( !$this->is_checkout_block_enabled() || !get_option('anomate_enable_marketing_consent_box') || !function_exists('__experimental_woocommerce_blocks_register_checkout_field') ) {
        return;
      }
      
      $marketing_box = wp_strip_all_tags( get_option('anomate_marketing_box') );

      if (!$marketing_box) {
        return;
      }
      
      __experimental_woocommerce_blocks_register_checkout_field( array(
        'id' => 'anomate/marketing',
        'label' => $marketing_box,
        'optionalLabel' => $marketing_box,
        'location' => 'contact',
        'type' => 'checkbox'
      ) );
    }

    public function is_checkout_block_enabled() {
      $checkout_page_id = wc_get_page_id('checkout');

      if ($checkout_page_id && $checkout_page_id != -1) {
        return WC_Blocks_Utils::has_block_in_page($checkout_page_id, 'woocommerce/checkout');
      }

      return false;
    }

    public function marketing_checkbox_process($order_id) {
      if ( !isset($_POST['anomate_marketing_nonce']) || !wp_verify_nonce($_POST['anomate_marketing_nonce'], 'anomate_marketing') ) {
        return;
      }

			if (isset($_POST['anomate_marketing']) && $_POST['anomate_marketing']) {
        update_post_meta($order_id, 'anomate_marketing', 1);
			}
		}

    public function marketing_checkbox($checkout) {
      if ( !get_option('anomate_enable_marketing_consent_box') ) {
        return;
      }

      $marketing_box = wp_strip_all_tags( get_option('anomate_marketing_box') );

      if (!$marketing_box) {
        return;
      }
      
      $tick_checkbox = get_option('anomate_tick_the_marketing_checkbox_by_default');
?>
      <div class="anomate-marketing-checkbox anomate-email-templates-paragraph-2-regular">
        <?php
          woocommerce_form_field( 'anomate_marketing', array(
            'type' => 'checkbox',
            'label' => $marketing_box,
          ), ( $tick_checkbox ? 1 : $checkout->get_value('anomate_marketing') ) );
        ?>
        <input type="hidden" name="anomate_marketing_nonce" value="<?php echo esc_attr( wp_create_nonce('anomate_marketing') ); ?>">
      </div>
<?php
    }
  }

  new AnomateCheckout();
?>