<?php
  class AnomateModals {
    private $anomate;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();

      add_action( 'wp_ajax_anomate_get_random_modal', array($this, 'get_random_modal') );
      add_action( 'wp_ajax_nopriv_anomate_get_random_modal', array($this, 'get_random_modal') );
    }
    
    public function get_random_modal() {
      if ( !isset($_GET['_wpnonce']) || !wp_verify_nonce($_GET['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      $html = false;
      $id = uniqid();

      if (isset($_GET['placement']) && $_GET['placement']) {
        $data = array(
          'placement' => sanitize_text_field($_GET['placement']),
        );

        if ( isset($_GET['exclude']) && !empty($_GET['exclude']) && is_array($_GET['exclude']) ) {
          $data['exclude'] = array_map('sanitize_text_field', $_GET['exclude']);
        }

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_get_modal', array(
            'body' => wp_json_encode($data),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          $body = json_decode( wp_remote_retrieve_body($response) );
          
          if (isset($body->html) && $body->html) {
            $html = $body->html;
          }

          if (isset($body->campaignId) && $body->campaignId) {
            $id = $body->campaignId;
          }
  
          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }

      echo wp_json_encode( array(
        'html' => $html,
        'id' => $id,
      ) );

      wp_die();
    }
  }

  new AnomateModals();
?>