<?php
  class AnomateTracking {
    private $anomate;
    private $base_webhook_url;
    
    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();

      add_action( 'wp_ajax_anomate_track', array($this, 'track') );
      add_action( 'wp_ajax_nopriv_anomate_track', array($this, 'track') );
      add_action( 'init', array($this, 'save_utm_tags_to_cookies') );
      add_action('woocommerce_checkout_order_processed', array($this, 'checkout_order_processed'), 10, 1);
      add_action('woocommerce_store_api_checkout_order_processed', array($this, 'api_checkout_order_processed'), 10, 1);
    }

    public function track_purchase($order_id) {
      try {
        $response = wp_remote_post( $this->base_webhook_url . '/anomate_track', array(
          'body' => wp_json_encode( array(
            'type' => 'purchase',
            'utm' => $this->get_utm_values(),
            'ip' => $_SERVER['REMOTE_ADDR'],
            'http_user_agent' => $_SERVER['HTTP_USER_AGENT'],
            'orderId' => $order_id
          ) ),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function api_checkout_order_processed($order) {
      $this->track_purchase( $order->get_id() );
    }

    public function checkout_order_processed($order_id) {
      $this->track_purchase($order_id);
    }

    public function get_tracked_utm_tags() {
      return array('utm_campaign', 'utm_source', 'utm_medium', 'utm_content', 'utm_term', 'acl');
    }

    public function save_utm_tags_to_cookies() {
      $get = $_GET;

      if ( !empty($get) ) {
				$utm_tags = $this->get_tracked_utm_tags();

				foreach ($get as $key => $value) {
					if ( in_array($key, $utm_tags) ) {
						setcookie('Anomate_' . $key, $value, time() + 2592000, '/');

						$_COOKIE['Anomate_' . $key] = $value;
					}
				}
			}
    }

    public function get_utm_values() {
      $values = array();

			foreach ($this->get_tracked_utm_tags() as $tag) {
				$values[$tag] = $this->get_utm_value($tag);
			}

			return $values;
    }

    public function get_utm_value($tag) {
      if (isset($_COOKIE['Anomate_' . $tag]) && $_COOKIE['Anomate_' . $tag]) {
        return $_COOKIE['Anomate_' . $tag];
      } else {
        $get = $_GET;

        if (isset($get[$tag]) && $get[$tag]) {
          return $get[$tag];
        }
      }

      return null;
    }

    public function track() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_die( esc_html__('Nonce verification failed', 'anomate-helper'), '', array(
          'response' => 403
        ) );
      }

      $data = $_POST;
      $data['utm'] = $this->get_utm_values();
      $data['ip'] = $_SERVER['REMOTE_ADDR'];
      $data['http_user_agent'] = $_SERVER['HTTP_USER_AGENT'];

      if (isset($data['url']) && $data['url']) {
        $data['url'] = strtok($data['url'], '?');

        if (strpos($data['url'], 'raffle-giveaway') !== false) {
          $parsed_url = parse_url($data['url']);
          
          if (isset($parsed_url['path']) && $parsed_url['path']) {
            $path_segments = explode( '/', trim($parsed_url['path'], '/') );

            if (isset($path_segments[count($path_segments) - 1]) && $path_segments[count($path_segments) - 1]) {
              $data['shopCampaignId'] = $path_segments[count($path_segments) - 1];
            }
          }
        }
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/anomate_track', array(
          'body' => wp_json_encode($data),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }

      wp_die();
    }
  }

  new AnomateTracking();
?>