<?php
  class AnomateUnsubscribe {
    private $anomate;
    private $base_webhook_url;
    private $plugin_path;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      $this->plugin_path = $this->anomate->get_plugin_path();

      add_action( 'init', array($this, 'create_endpoint') );
      add_action( 'template_redirect', array($this, 'template_redirect') );
      add_action( 'wp_ajax_anomate_unsubscribe_save_preferences', array($this, 'save_preferences') );
      add_action( 'wp_ajax_nopriv_anomate_unsubscribe_save_preferences', array($this, 'save_preferences') );
      add_action( 'wp_ajax_anomate_unsubscribe', array($this, 'ajax_unsubscribe') );
      add_action( 'wp_ajax_nopriv_anomate_unsubscribe', array($this, 'ajax_unsubscribe') );
    }

    public function get_string($string, $email = '') {
      $strings = array(
        'subscribe_title' => __('Your preferences have been saved', 'anomate-helper'),
        'subscribe_description' =>
          // Translators: %s is the email address that has been subscribed.
          sprintf(__('Your email address %s have been successfully subscribed.', 'anomate-helper'), $email),
        'unsubscribe_title' => __('Unsubscribed successful', 'anomate-helper'),
        'unsubscribe_description' =>
          // Translators: %s is the email address that has been unsubscribed.
          sprintf(__('Your email address %s have been successfully unsubscribed from all our email lists.', 'anomate-helper'), $email),
      );

      if (isset($strings[$string])) {
        return $strings[$string];
      }

      return '';
    }

    public function save_preferences() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      if (isset($_POST['email']) && $_POST['email']) {
        if ( !isset($_POST['marketingCategories']) || empty($_POST['marketingCategories']) ) {
          echo wp_json_encode( $this->unsubscribe($_POST) );
        } else {
          try {
            $response = wp_remote_post( $this->base_webhook_url . '/anomate_save_subscriber_preferences', array(
              'body' => wp_json_encode($_POST),
              'headers' => array(
                'Content-Type' => 'application/json',
              ),
              'timeout' => 60,
            ) );
  
            if ( is_wp_error($response) ) {
              throw new Exception( 'WP_Error: ' . $response->get_error_message() );

              echo wp_json_encode(false);
            } else {
              echo wp_json_encode( array(
                'title' => $this->get_string('subscribe_title'),
                'description' => $this->get_string('subscribe_description'),
              ) );
            }
          } catch (Exception $e) {
            error_log( 'Error: ' . $e->getMessage() );

            echo wp_json_encode(false);
          }
        }
      } else {
        echo wp_json_encode(false);
      }

      wp_die();
    }

    public function unsubscribe($post_data) {
      try {
        $response = wp_remote_post( $this->base_webhook_url . '/anomate_unsubscribe', array(
          'body' => wp_json_encode($post_data),
          'headers' => array(
            'Content-Type' => 'application/json',
          ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );

          return false;
        } else {
          return array(
            'title' => $this->get_string('unsubscribe_title'),
            'description' => $this->get_string('unsubscribe_description', $post_data['email']),
          );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );

        return false;
      }
    }

    public function ajax_unsubscribe() {
      if ( !isset($_POST['_wpnonce']) || !wp_verify_nonce($_POST['_wpnonce'], 'anomate') ) {
        wp_send_json_error( array(
          'message' => esc_html__('Nonce verification failed', 'anomate-helper'),
        ) );

        wp_die();
      }

      if (isset($_POST['email']) && $_POST['email']) {
        echo wp_json_encode( $this->unsubscribe($_POST) );
      } else {
        echo wp_json_encode(false);
      }

      wp_die();
    }

    public function template_redirect() {
      global $wp_query;

      if ( isset($wp_query->query_vars['unsubscribe']) ) {
        try {
          $get = $_GET;

          $response = wp_remote_post( $this->base_webhook_url . '/anomate_subscriber', array(
            'body' => wp_json_encode( array(
              'hash' => isset($get['acl']) && $get['acl'] ? $get['acl'] : null,
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $body = json_decode( wp_remote_retrieve_body($response) );
            $subscriber = isset($body->subscriber) && $body->subscriber ? $body->subscriber : null;
            $marketing_categories = isset($body->marketingCategories) && $body->marketingCategories ? $body->marketingCategories : null;
            $subscribe_title = $this->get_string('subscribe_title');
            $subscribe_description = $this->get_string('subscribe_description');
            $unsubscribe_title = $this->get_string('unsubscribe_title');
            $unsubscribe_description = $this->get_string('unsubscribe_description');

            if (isset($get['cmc']) && $get['cmc'] == 1 && isset($get['acl']) && $get['acl']) {
              $action = '';

              if (isset($get['subscribe']) && $get['subscribe'] == 1) {
                $action = 'anomate_consent_manager_campaign_entry';
              } elseif (isset($get['unsubscribe']) && $get['unsubscribe'] == 1) {
                $action = 'anomate_consent_manager_campaign_unsubscribe';
              }

              if ($action) {
                wp_remote_post( $this->base_webhook_url . '/' . $action, array(
                  'body' => wp_json_encode( array(
                    'hash' => $get['acl'],
                  ) ),
                  'headers' => array(
                    'Content-Type' => 'application/json',
                  ),
                  'timeout' => 60,
                ) );
              }
            }

            require_once $this->plugin_path . '/templates/unsubscribe/index.php';
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );

          $this->anomate->redirect404();
        }
        
        exit;
      }
    }

    public function create_endpoint() {
      add_rewrite_endpoint('unsubscribe', EP_ROOT);
    }
  }

  new AnomateUnsubscribe();
?>