<?php
  class AnomateViewEmail {
    private $anomate;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();

      add_action( 'init', array($this, 'create_endpoint') );
      add_action('template_redirect', array($this, 'template_redirect'), 999);
    }

    public function template_redirect() {
      global $wp_query;

      if ( isset($wp_query->query_vars['view-email']) ) {
        $get = $_GET;
        $hash = isset($get['hash']) ? sanitize_text_field($get['hash']) : '';

        if ( empty($hash) || !preg_match('/^[a-f0-9]{32}$/', $hash) ) {
          $this->anomate->redirect404();
        }

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/anomate_view_email', array(
            'body' => wp_json_encode( array(
              'hash' => $hash,
            ) ),
            'headers' => array(
              'Content-Type' => 'application/json',
            ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          } else {
            $body = json_decode(wp_remote_retrieve_body($response));

            if ( $body && !is_object($body) ) {
              echo $body;
            } else {
              $this->anomate->redirect404();
            }
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
          
          $this->anomate->redirect404();
        }
        
        exit;
      }
    }

    public function create_endpoint() {
      add_rewrite_endpoint('view-email', EP_ROOT);
    }
  }

  new AnomateViewEmail();
?>