<?php
  class AnomateHelperWebhooksPosts {
    private $anomate;
    private $api_helper;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->api_helper = new AnomateHelperApi();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();

      add_action('created_category', array($this, 'create_category'), 10, 3);
      add_action('created_post_tag', array($this, 'create_tag'), 10, 3);
      add_action('edited_category', array($this, 'update_category'), 10, 3);
      add_action('edited_post_tag', array($this, 'update_tag'), 10, 3);
      add_action('delete_term', array($this, 'delete_term'), 10, 5);
      add_action('save_post', array($this, 'save_post'), 10, 3);
      add_action('delete_post', array($this, 'delete_post'), 10, 2);
    }

    public function delete_post($post_id, $post) {
      if ($post->post_type == 'post') {
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/post.deleted', array(
            'body' => wp_json_encode( array(
              'id' => intval($post_id),
            ) ),
            'headers' => $this->api_helper->get_webhook_headers( array(
              'resource' => 'post',
              'event' => 'deleted',
            ) ),
            'timeout' => 60,
          ) );
  
          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch(Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }
    }

    public function save_post($post_id, $post, $update) {
      if ($post->post_status != 'inherit' && $post->post_type == 'post') {
        $event = $update ? 'updated' : 'created';
        
        try {
          $response = wp_remote_post( $this->base_webhook_url . '/post.created', array(
            'body' => wp_json_encode( $this->api_helper->get_post_object($post_id) ),
            'headers' => $this->api_helper->get_webhook_headers( array(
              'resource' => 'post',
              'event' => $event,
            ) ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch(Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }
    }

    public function delete_term($term, $tt_id, $taxonomy) {
      if ($taxonomy == 'category' || $taxonomy == 'post_tag') {
        $resource = $taxonomy == 'category' ? 'posts/categorie' : 'posts/tag';
        $webhook_resource = $taxonomy == 'post_tag' ? 'tag' : $taxonomy;

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/' . $webhook_resource . '.deleted', array(
            'body' => wp_json_encode( array(
              'id' => intval($tt_id),
            ) ),
            'headers' => $this->api_helper->get_webhook_headers( array(
              'resource' => $resource,
              'event' => 'deleted',
            ) ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch(Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }
    }

    public function update_tag($term_id) {
      $tag = get_term($term_id, 'post_tag');

      if ( is_wp_error($tag) || empty($tag) ) {
        return null;
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/tag.updated', array(
          'body' => wp_json_encode($tag),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'posts/tag',
            'event' => 'updated',
          ) ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch(Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function update_category($term_id) {
      $category = get_term($term_id, 'category');

      if ( is_wp_error($category) || empty($category) ) {
        return null;
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/category.updated', array(
          'body' => wp_json_encode($category),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'posts/categorie',
            'event' => 'updated',
          ) ),
          'timeout' => 60,
        ) );
        
        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch(Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function create_tag($term_id) {
      $tag = get_term($term_id, 'post_tag');

      if ( is_wp_error($tag) || empty($tag) ) {
        return null;
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/tag.created', array(
          'body' => wp_json_encode($tag),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'posts/tag',
            'event' => 'created',
          ) ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch(Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function create_category($term_id) {
      $category = get_term($term_id, 'category');

      if ( is_wp_error($category) || empty($category) ) {
        return null;
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/category.created', array(
          'body' => wp_json_encode($category),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'posts/categorie',
            'event' => 'created',
          ) ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch(Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }
  }

  new AnomateHelperWebhooksPosts();
?>