<?php
  class AnomateHelperWebhooksProducts {
    private $anomate;
    private $api_helper;
    private $base_webhook_url;

    public function __construct() {
      $this->anomate = new AnomateHelper();
      $this->api_helper = new AnomateHelperApi();
      $this->base_webhook_url = $this->anomate->get_base_webhook_url();
      
      add_action('created_product_cat', array($this, 'create_product_category'), 10, 3);
      add_action('created_product_tag', array($this, 'create_product_tag'), 10, 3);
      add_action('edited_product_cat', array($this, 'update_product_category'), 10, 3);
      add_action('edited_product_tag', array($this, 'update_product_tag'), 10, 3);
      add_action('delete_term', array($this, 'delete_term'), 10, 5);
    }

    public function delete_term($term, $tt_id, $taxonomy) {
      if ($taxonomy == 'product_cat' || $taxonomy == 'product_tag') {
        $webhook_resource = $taxonomy == 'product_cat' ? 'product-category' : 'product-tag';
        $resource = $taxonomy == 'product_cat' ? 'products/categorie' : 'products/tag';

        try {
          $response = wp_remote_post( $this->base_webhook_url . '/' . $webhook_resource . '.deleted', array(
            'body' => wp_json_encode( array(
              'id' => intval($tt_id),
            ) ),
            'headers' => $this->api_helper->get_webhook_headers( array(
              'resource' => $resource,
              'event' => 'deleted',
            ) ),
            'timeout' => 60,
          ) );

          if ( is_wp_error($response) ) {
            throw new Exception( 'WP_Error: ' . $response->get_error_message() );
          }
        } catch (Exception $e) {
          error_log( 'Error: ' . $e->getMessage() );
        }
      }
    }

    public function update_product_tag($term_id) {
      $tag = get_term($term_id, 'product_tag');

      if ( is_wp_error($tag) || empty($tag) ) {
        return null;
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/product-tag.updated', array(
          'body' => wp_json_encode( $this->get_product_tag_object($term_id) ),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'products/tag',
            'event' => 'updated',
          ) ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function update_product_category($term_id) {
      $category = get_term($term_id, 'product_cat');

      if ( is_wp_error($category) || empty($category) ) {
        return null;
      }
      try {
        $response = wp_remote_post( $this->base_webhook_url . '/product-category.updated', array(
          'body' => wp_json_encode( $this->get_product_category_object($term_id) ),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'products/category',
            'event' => 'updated',
          ) ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function create_product_tag($term_id) {
      $tag = get_term($term_id, 'product_tag');

      if ( is_wp_error($tag) || empty($tag) ) {
        return null;
      }
      try {
        $response = wp_remote_post( $this->base_webhook_url . '/product-tag.created', array(
          'body' => wp_json_encode( $this->get_product_tag_object($term_id) ),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'products/tag',
            'event' => 'created',
          ) ),
          'timeout' => 60,
        ) );

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function create_product_category($term_id) {
      $category = get_term($term_id, 'product_cat');

      if ( is_wp_error($category) || empty($category) ) {
        return null;
      }

      try {
        $response = wp_remote_post( $this->base_webhook_url . '/product-category.created', array(
          'body' => wp_json_encode( $this->get_product_category_object($term_id) ),
          'headers' => $this->api_helper->get_webhook_headers( array(
            'resource' => 'products/category',
            'event' => 'created',
          ) ),
          'timeout' => 60,
        ) ); 

        if ( is_wp_error($response) ) {
          throw new Exception( 'WP_Error: ' . $response->get_error_message() );
        }
      } catch (Exception $e) {
        error_log( 'Error: ' . $e->getMessage() );
      }
    }

    public function get_product_tag_object($tag_id) {
      $tag = get_term($tag_id, 'product_tag');
  
      if ( is_wp_error($tag) || empty($tag) ) {
        return null;
      }
  
      $tag_data = array(
        'id' => $tag->term_id,
        'name' => $tag->name,
        'slug' => $tag->slug,
        'description' => $tag->description,
        'count' => $tag->count,
        '_links' => array(
          'self' => array( array(
            'href' => get_term_link($tag),
          ) ),
          'collection' => array( array(
            'href' => get_term_link($tag),
          ) ),
        ),
      );
  
      return $tag_data;
    }

    public function get_category_image_object($category_id) {
      $attachment_id = get_term_meta($category_id, 'thumbnail_id', true);

      if ( empty($attachment_id) ) {
        return null;
      }
      
      $attachment_url = wp_get_attachment_url($attachment_id);
      $attachment_post = get_post($attachment_id);

      return array(
        'id' => intval($attachment_id),
        'date_created' => $attachment_post->post_date,
        'date_created_gmt' => $attachment_post->post_date_gmt,
        'date_modified' => $attachment_post->post_modified,
        'date_modified_gmt' => $attachment_post->post_modified_gmt,
        'src' => $attachment_url,
        'name' => get_the_title($attachment_id),
        'alt' => get_post_meta($attachment_id, '_wp_attachment_image_alt', true),
      );
    }

    public function get_product_category_object($category_id) {
      $category = get_term($category_id, 'product_cat');
  
      if ( is_wp_error( $category ) || empty( $category ) ) {
        return null;
      }
  
      $category_data = array(
        'id' => $category->term_id,
        'name' => $category->name,
        'slug' => $category->slug,
        'parent' => $category->parent,
        'description' => $category->description,
        'display' => 'default',
        'image' => $this->get_category_image_object($category_id),
        'menu_order' => $category->menu_order,
        'count' => $category->count,
        '_links' => array(
          'self' => array( array(
            'href' => get_term_link($category),
          ) ),
          'collection' => array( array(
            'href' => get_term_link($category),
          ) ),
        ),
      );
  
      return $category_data;
    }
  }

  new AnomateHelperWebhooksProducts();
?>