<?php
  global $wp_query;

  $logo = get_option('anomate_logo');
  $brand_name = get_option('anomate_brand_name');
  $home_url = esc_url( home_url('/') );
?>
<!doctype html>
  <html lang="en">
  <head>
    <?php wp_head(); ?>
    <title><?php esc_attr_e('Customer Survey', 'anomate-helper'); ?><?php if ($brand_name) : ?> - <?php echo esc_attr($brand_name); ?><?php endif; ?></title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
  </head>
  <body class="anomate anomate-cs">
    <?php if ($logo) : ?>
      <div class="anomate-sh-logo">
        <a href="<?php echo esc_attr($home_url); ?>" class="anomate-sh-logo__link">
          <img src="<?php echo esc_attr($logo); ?>" alt="<?php echo esc_attr($brand_name ?? $brand_name); ?>" class="anomate-sh-logo__image">
        </a>
      </div>
    <?php endif; ?>
    <div class="anomate-sh-section">
      <?php if ($already_submitted) : ?>
        <div class="anomate-cs-thanks anomate-cs-thanks_active">
          <h3 class="anomate-cs-thanks__title"><?php esc_html_e('This survey has been submitted and is no longer accessible', 'anomate-helper'); ?></h3>
          <div class="anomate-cs-thanks__icon">
            <svg xmlns="http://www.w3.org/2000/svg" width="48" height="49" viewBox="0 0 48 49" fill="none" class="anomate-cs-thanks__icon-svg">
              <path d="M32.7653 17.0469H30.5669C30.0887 17.0469 29.634 17.2766 29.3528 17.6703L21.984 27.8891L18.6465 23.2578C18.3653 22.8688 17.9153 22.6344 17.4324 22.6344H15.234C14.9293 22.6344 14.7512 22.9812 14.9293 23.2297L20.7699 31.3297C20.9079 31.5223 21.0898 31.6792 21.3005 31.7874C21.5113 31.8957 21.7448 31.9522 21.9817 31.9522C22.2186 31.9522 22.4521 31.8957 22.6628 31.7874C22.8735 31.6792 23.0554 31.5223 23.1934 31.3297L33.0653 17.6422C33.2481 17.3938 33.07 17.0469 32.7653 17.0469Z" fill="#52C41A"/>
              <path d="M24 3.5C12.4031 3.5 3 12.9031 3 24.5C3 36.0969 12.4031 45.5 24 45.5C35.5969 45.5 45 36.0969 45 24.5C45 12.9031 35.5969 3.5 24 3.5ZM24 41.9375C14.3719 41.9375 6.5625 34.1281 6.5625 24.5C6.5625 14.8719 14.3719 7.0625 24 7.0625C33.6281 7.0625 41.4375 14.8719 41.4375 24.5C41.4375 34.1281 33.6281 41.9375 24 41.9375Z" fill="#52C41A"/>
            </svg>
          </div>
          <div class="anomate-cs-thanks__bottom">
            <div class="anomate-cs-thanks__bottom-label"><?php esc_html_e('Thank you for your time. Your feedback is important to us.', 'anomate-helper'); ?></div>
            <?php if ($brand_name) : ?>
              <div class="anomate-cs-thanks__bottom-team"><?php echo esc_attr($brand_name); ?></div>
            <?php endif; ?>
          </div>
        </div>
      <?php else : ?>
        <?php $questions_count = count($questions); ?>
        <div class="anomate-cs-form">
          <div class="anomate-cs-form__progress">
            <div class="anomate-cs-progress">
              <div class="anomate-cs-progress__current" style="width: <?php echo esc_attr(1 / $questions_count * 100); ?>%;"></div>
            </div>
            <div class="anomate-cs-form__progress-label">
              <?php
                // Translators: %1$s is a current step number
                // Translators: %2$s is a total number of questions
                printf( esc_html__('Question %1$s of %2$s'), '<span class="anomate-cs-form__progress-current-step">1</span>', esc_attr($questions_count) );
              ?>
            </div>
          </div>
          <form action="<?php echo esc_attr($home_url); ?>" class="anomate-cs-form__inner">
            <ul class="anomate-cs-steps">
              <?php foreach ($questions as $key => $question) : ?>
                <?php $is_mandatory = (isset($question->mandatory) && $question->mandatory); ?>
                <li class="anomate-cs-steps__item<?php if ($key == 0) : ?> anomate-cs-steps__item_active<?php endif; ?>">
                  <div class="anomate-cs-question">
                    <div class="anomate-cs-question__content<?php if ($is_mandatory) : ?> anomate-cs-question__content_required<?php endif; ?>" data-type="<?php echo esc_attr($question->type); ?>">
                      <label for="<?php echo esc_attr($question->_id); ?>" class="anomate-cs-question__label"><?php echo esc_attr($question->question); ?><?php if ($is_mandatory) : ?>*<?php endif; ?></label>
                      <?php if ( in_array( $question->type, array('radio', 'checkbox', 'rating') ) ) : ?>
                        <div class="anomate-cs-question__options">
                          <ul class="anomate-cs-options anomate-cs-options_<?php echo esc_attr($question->type); ?>">
                            <?php foreach ($question->answers as $answer) : ?>
                              <li class="anomate-cs-options__item anomate-cs-option anomate-cs-option_<?php echo esc_attr($question->type); ?>">
                                <input type="<?php echo $question->type == 'checkbox' ? 'checkbox' : 'radio'; ?>" name="<?php echo esc_attr($question->_id); ?><?php if ($question->type == 'checkbox') : ?>[]<?php endif; ?>" class="anomate-cs-option__input" id="anomate-cs-option__input_<?php echo esc_attr($answer->_id); ?>" value="<?php echo esc_attr($answer->_id); ?>">
                                <label for="anomate-cs-option__input_<?php echo esc_attr($answer->_id); ?>" class="anomate-cs-option__label anomate-cs-option__label_<?php echo esc_attr($question->type); ?>"><?php echo esc_attr($answer->value); ?></label>
                              </li>
                            <?php endforeach; ?>
                          </ul>
                        </div>
                      <?php else : ?>
                        <textarea name="<?php echo esc_attr($question->_id); ?>" id="<?php echo esc_attr($question->_id); ?>" cols="30" rows="10" class="anomate-cs-textarea"></textarea>
                      <?php endif; ?>
                    </div>
                    <div class="anomate-cs-question__footer">
                      <?php if ( $key == ($questions_count - 1) ) : ?>
                        <button type="submit" class="anomate-cs-question__btn anomate-cs-question__btn_primary anomate-cs-question__btn_disabled" disabled><?php esc_html_e('Submit', 'anomate-helper'); ?></button>
                      <?php else : ?>
                        <?php if ($key > 0) : ?>
                          <a href="#" class="anomate-cs-question__btn anomate-cs-question__btn_back"><?php esc_html_e('Back', 'anomate-helper'); ?></a>
                        <?php endif; ?>
                        <a href="#" class="anomate-cs-question__btn anomate-cs-question__btn_primary anomate-cs-question__btn_next anomate-cs-question__btn_disabled"><?php esc_html_e('Next', 'anomate-helper'); ?></a>
                      <?php endif; ?>
                    </div>
                  </div>
                </li>
              <?php endforeach; ?>
            </ul>
            <input type="hidden" name="action" value="anomate_save_customer_survey_entry">
            <input type="hidden" name="shop_campaign_id" value="<?php echo esc_attr($wp_query->query_vars['anomate_survey_id']); ?>">
            <input type="hidden" name="acl" value="<?php echo esc_attr($_GET['acl']); ?>">
            <input type="hidden" name="_wpnonce" value="<?php echo esc_attr( wp_create_nonce('anomate') ); ?>">
          </form>
        </div>
        <div class="anomate-cs-thanks">
          <h3 class="anomate-cs-thanks__title"><?php esc_html_e('Thank you for sharing!', 'anomate-helper'); ?></h3>
          <div class="anomate-cs-thanks__icon">
            <svg xmlns="http://www.w3.org/2000/svg" width="48" height="49" viewBox="0 0 48 49" fill="none" class="anomate-cs-thanks__icon-svg">
              <path d="M32.7653 17.0469H30.5669C30.0887 17.0469 29.634 17.2766 29.3528 17.6703L21.984 27.8891L18.6465 23.2578C18.3653 22.8688 17.9153 22.6344 17.4324 22.6344H15.234C14.9293 22.6344 14.7512 22.9812 14.9293 23.2297L20.7699 31.3297C20.9079 31.5223 21.0898 31.6792 21.3005 31.7874C21.5113 31.8957 21.7448 31.9522 21.9817 31.9522C22.2186 31.9522 22.4521 31.8957 22.6628 31.7874C22.8735 31.6792 23.0554 31.5223 23.1934 31.3297L33.0653 17.6422C33.2481 17.3938 33.07 17.0469 32.7653 17.0469Z" fill="#52C41A"/>
              <path d="M24 3.5C12.4031 3.5 3 12.9031 3 24.5C3 36.0969 12.4031 45.5 24 45.5C35.5969 45.5 45 36.0969 45 24.5C45 12.9031 35.5969 3.5 24 3.5ZM24 41.9375C14.3719 41.9375 6.5625 34.1281 6.5625 24.5C6.5625 14.8719 14.3719 7.0625 24 7.0625C33.6281 7.0625 41.4375 14.8719 41.4375 24.5C41.4375 34.1281 33.6281 41.9375 24 41.9375Z" fill="#52C41A"/>
            </svg>
          </div>
          <div class="anomate-cs-thanks__subtitle"><?php esc_html_e('Your comment was sent successfully. Check your email to collect your prize.', 'anomate-helper'); ?></div>
          <div class="anomate-cs-thanks__bottom">
            <div class="anomate-cs-thanks__bottom-label"><?php esc_html_e('Thank you for your time. Your feedback is important to us.', 'anomate-helper'); ?></div>
            <?php if ($brand_name) : ?>
              <div class="anomate-cs-thanks__bottom-team"><?php echo esc_attr($brand_name); ?></div>
            <?php endif; ?>
          </div>
        </div>
      <?php endif; ?>
    </div>
    <div class="anomate-sh-copyright">
      <?php if ($brand_name) : ?>
        <div class="anomate-sh-copyright__name">
          <a href="<?php echo esc_attr($home_url); ?>" class="anomate-sh-copyright__name-link"><?php echo esc_attr($brand_name); ?></a>
        </div>
      <?php endif; ?>
      <a href="<?php echo esc_attr($home_url); ?>" class="anomate-sh-copyright__link"><?php echo esc_attr( trim(str_replace( 'https://', '', str_replace('http://', '', $home_url) ), '/') ); ?></a>
    </div>
    <?php wp_footer(); ?>
  </body>
</html>