<?php
  global $wp_query;

  $logo = get_option('anomate_logo');
  $brand_name = get_option('anomate_brand_name');
  $home_url = esc_url( home_url('/') );
  $enable_gdpr_consent_box = get_option('anomate_enable_gdpr_consent_box');
  $get = $_GET;
?>
<!doctype html>
  <html lang="en">
  <head>
    <title><?php esc_attr_e('Product Review', 'anomate-helper'); ?></title>
    <?php wp_head(); ?>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
  </head>
  <body class="anomate anomate-cs">
    <?php if ($logo) : ?>
      <div class="anomate-sh-logo">
        <a href="<?php echo esc_attr($home_url); ?>" class="anomate-sh-logo__link">
          <img src="<?php echo esc_attr($logo); ?>" alt="<?php echo esc_attr($brand_name ?? $brand_name); ?>" class="anomate-sh-logo__image">
        </a>
      </div>
    <?php endif; ?>
    <div class="anomate-sh-section anomate-sh-section_fh">
      <?php if ($get['rating'] >= 4) : ?>
        <div class="anomate-pr-external">
          <h1 class="anomate-pr-external__title"><?php esc_html_e('Thanks for making us happy!', 'anomate-helper'); ?></h1>
          <div class="anomate-pr-external__description">
            <p>
              <?php
                // Translators: %s is a brand name
                $with = $brand_name ? sprintf(esc_html__(' with %s', 'anomate-helper'), $brand_name) : '';

                // Translators: %s is a brand name
                printf( esc_html__('It’s great to hear that you’re happy with the experience you’ve had%s.', 'anomate-helper'), esc_attr($with) );
              ?>
            </p>
            <p><?php esc_html_e('Our team is working hard to constantly improve our products and services and we value your feedback!', 'anomate-helper'); ?></p>
            <p><?php esc_html_e('It would make us even happier if you could spare another moment to share your thoughts with other people.', 'anomate-helper'); ?></p>
          </div>
          <ul class="anomate-pr-external__list anomate-review-services">
            <?php foreach ($review_services as $service => $url) : ?>
              <li class="anomate-review-services__item anomate-review-service">
                <a href="<?php echo esc_attr($url); ?>" target="_blank" class="anomate-review-service__link" data-service="<?php echo esc_attr($service); ?>">
                  <?php
                    if (isset($reviews_map[$service]['icon']) && $reviews_map[$service]['icon']) {
                      echo $reviews_map[$service]['icon'];
                    }
                  ?>
                  <?php if (isset($reviews_map[$service]['name']) && $reviews_map[$service]['name']) : ?>
                    <span class="anomate-review-service__text">
                      <span class="anomate-review-service__label">
                        <?php
                          // Translators: %s is a review service name
                          printf( esc_html__('Leave a review on %s', 'anomate-helper'), esc_attr($reviews_map[$service]['name']) );
                        ?>
                      </span>
                      <svg xmlns="http://www.w3.org/2000/svg" width="25" height="25" viewBox="0 0 25 25" fill="none" class="anomate-review-service__icon">
                        <path d="M13.5 11.5L18.5 6.5M18.5 6.5H15.1667M18.5 6.5V9.83333M18.5 13.8333V17.1667C18.5 17.5203 18.3595 17.8594 18.1095 18.1095C17.8594 18.3595 17.5203 18.5 17.1667 18.5H7.83333C7.47971 18.5 7.14057 18.3595 6.89052 18.1095C6.64048 17.8594 6.5 17.5203 6.5 17.1667V7.83333C6.5 7.47971 6.64048 7.14057 6.89052 6.89052C7.14057 6.64048 7.47971 6.5 7.83333 6.5H11.1667" stroke="#262626" stroke-width="1.33333" stroke-linecap="round" stroke-linejoin="round"/>
                      </svg>
                    </span>
                  <?php endif; ?>
                </a>
              </li>
            <?php endforeach; ?>
          </ul>
          <div class="anomate-pr-external__signature-p"><?php esc_html_e('We appreciate your valuable feedback and time.', 'anomate-helper'); ?></div>
          <?php if ($brand_name) : ?>
            <div class="anomate-pr-external__signature">
              <?php
                // Translators: %s is a brand name
                printf( esc_html__('%s team', 'anomate-helper'), esc_attr($brand_name) );
              ?>
            </div>
          <?php endif; ?>
        </div>
        <input type="hidden" name="shop_campaign_id" id="shop_campaign_id" value="<?php echo esc_attr($wp_query->query_vars['anomate_pr_id']); ?>">
        <input type="hidden" name="acl" id="acl" value="<?php echo esc_attr($get['acl']); ?>">
        <input type="hidden" name="stars" id="stars" value="<?php echo esc_attr($get['rating']); ?>">
      <?php else : ?>
        <div class="anomate-cs-form">
          <form action="<?php echo esc_attr($home_url); ?>" class="anomate-cs-form__inner anomate-cs-form__inner_product-review">
            <div class="anomate-cs-form__head anomate-pr-head">
              <h1 class="anomate-pr-head__title"><?php esc_html_e('How can we improve?', 'anomate-helper'); ?></h1>
              <div class="anomate-pr-head__description"><?php esc_html_e('It’s our goal to deliver the highest level of service to all out clients, and we’d love to learn a little bit more about what prompted your feedbback.', 'anomate-helper'); ?></div>
            </div>
            <ul class="anomate-pr-steps">
              <?php foreach ($questions as $key => $question) : ?>
                <?php $is_mandatory = (isset($question->mandatory) && $question->mandatory); ?>
                <li class="anomate-pr-steps__item anomate-pr-question<?php if ($is_mandatory) : ?> anomate-pr-question_mandatory<?php endif; ?>">
                  <label for="<?php echo esc_attr($question->_id); ?>" class="anomate-pr-question__label"><?php echo esc_attr($question->question); ?><?php if ($is_mandatory) : ?>*<?php endif; ?></label>
                  <div class="anomate-pr-question__options">
                    <ul class="anomate-cs-options anomate-cs-options_rating">
                      <?php foreach ($question->answers as $answer) : ?>
                        <li class="anomate-cs-options__item anomate-cs-option anomate-cs-option_rating">
                          <input type="radio" name="<?php echo esc_attr($question->_id); ?>" class="anomate-cs-option__input" id="anomate-cs-option__input_<?php echo esc_attr($answer->_id); ?>" value="<?php echo esc_attr($answer->_id); ?>">
                          <label for="anomate-cs-option__input_<?php echo esc_attr($answer->_id); ?>" class="anomate-cs-option__label anomate-cs-option__label_rating"><?php echo esc_attr($answer->value); ?></label>
                        </li>
                      <?php endforeach; ?>
                    </ul>
                  </div>
                </li>
              <?php endforeach; ?>
              <li class="anomate-pr-steps__item anomate-pr-question">
                <label for="field_comments" class="anomate-pr-question__label"><?php esc_html_e('Do you have any other comments or feedback you\'d like to share with us?', 'anomate-helper'); ?></label>
                <textarea name="textarea_comments" id="field_comments" cols="30" rows="10" class="anomate-cs-textarea anomate-cs-textarea_pr" placeholder="<?php esc_html_e('Write your comments here', 'anomate-helper'); ?>"></textarea>
              </li>
            </ul>
            <div class="anomate-pr-footer">
              <?php if ($enable_gdpr_consent_box) : ?>
                <?php
                  $consent_box = get_option('anomate_consent_box');  
                  $tick_checkbox = get_option('anomate_tick_the_consent_checkbox_by_default');
                ?>
                <?php if ($consent_box) : ?>
                  <div class="anomate-checkbox anomate-email-templates-paragraph-2-regular">
                    <input type="checkbox" name="gdpr" id="product-review_gdpr" class="anomate-checkbox__input" required<?php if ($tick_checkbox) : ?> checked<?php endif; ?>>
                    <label for="product-review_gdpr" class="anomate-checkbox__label anomate-pr-footer__label"><?php echo wp_kses_post($consent_box); ?></label>
                  </div>
                <?php endif; ?>
              <?php endif; ?>
              <button type="submit" class="anomate-cs-question__btn anomate-cs-question__btn_disabled anomate-cs-question__btn_primary anomate-cs-question__btn_fw" disabled><?php esc_html_e('Send', 'anomate-helper'); ?></button>
            </div>
            <input type="hidden" name="action" value="anomate_negative_feedback">
            <input type="hidden" name="shop_campaign_id" value="<?php echo esc_attr($wp_query->query_vars['anomate_pr_id']); ?>">
            <input type="hidden" name="acl" value="<?php echo esc_attr($get['acl']); ?>">
            <input type="hidden" name="stars" value="<?php echo esc_attr($get['rating']); ?>">
            <input type="hidden" name="_wpnonce" value="<?php echo esc_attr( wp_create_nonce('anomate') ); ?>">
          </form>
        </div>
        <div class="anomate-cs-thanks">
          <h3 class="anomate-cs-thanks__title"><?php esc_html_e('How can we improve?', 'anomate-helper'); ?></h3>
          <div class="anomate-cs-thanks__icon">
            <svg xmlns="http://www.w3.org/2000/svg" width="48" height="49" viewBox="0 0 48 49" fill="none" class="anomate-cs-thanks__icon-svg">
              <path d="M32.7653 17.0469H30.5669C30.0887 17.0469 29.634 17.2766 29.3528 17.6703L21.984 27.8891L18.6465 23.2578C18.3653 22.8688 17.9153 22.6344 17.4324 22.6344H15.234C14.9293 22.6344 14.7512 22.9812 14.9293 23.2297L20.7699 31.3297C20.9079 31.5223 21.0898 31.6792 21.3005 31.7874C21.5113 31.8957 21.7448 31.9522 21.9817 31.9522C22.2186 31.9522 22.4521 31.8957 22.6628 31.7874C22.8735 31.6792 23.0554 31.5223 23.1934 31.3297L33.0653 17.6422C33.2481 17.3938 33.07 17.0469 32.7653 17.0469Z" fill="#52C41A"/>
              <path d="M24 3.5C12.4031 3.5 3 12.9031 3 24.5C3 36.0969 12.4031 45.5 24 45.5C35.5969 45.5 45 36.0969 45 24.5C45 12.9031 35.5969 3.5 24 3.5ZM24 41.9375C14.3719 41.9375 6.5625 34.1281 6.5625 24.5C6.5625 14.8719 14.3719 7.0625 24 7.0625C33.6281 7.0625 41.4375 14.8719 41.4375 24.5C41.4375 34.1281 33.6281 41.9375 24 41.9375Z" fill="#52C41A"/>
            </svg>
          </div>
          <div class="anomate-cs-thanks__subtitle"><?php esc_html_e('Your comment was sent successfully.', 'anomate-helper'); ?></div>
          <div class="anomate-cs-thanks__bottom">
            <div class="anomate-cs-thanks__bottom-label"><?php esc_html_e('Thank you for your time. Your feedback is important for us.', 'anomate-helper'); ?></div>
          </div>
        </div>
      <?php endif; ?>
    </div>
    <div class="anomate-sh-copyright">
      <?php if ($brand_name) : ?>
        <div class="anomate-sh-copyright__name">
          <a href="<?php echo esc_attr($home_url); ?>" class="anomate-sh-copyright__name-link"><?php echo esc_attr($brand_name); ?></a>
        </div>
      <?php endif; ?>
      <a href="<?php echo esc_attr($home_url); ?>" class="anomate-sh-copyright__link"><?php echo esc_attr( trim(str_replace( 'https://', '', str_replace('http://', '', $home_url) ), '/') ); ?></a>
    </div>
    <?php wp_footer(); ?>
  </body>
</html>