<?php
  $not_empty_marketing_categories = ( isset($subscriber->marketingCategories) && !empty($subscriber->marketingCategories) );
  $get = $_GET;
  $is_unsubscribe = (isset($get['unsubscribe']) && $get['unsubscribe'] == 1) ? true : false;
  $is_subscribe = (isset($get['subscribe']) && $get['subscribe'] == 1) ? true : false;
  $title = __('Unsubscription preferences', 'anomate-helper');
  $description = __('Please enter your email address and select the lists that you would like to be included or removed from:', 'anomate-helper');
  $logo = get_option('anomate_logo');
  $brand_name = get_option('anomate_brand_name');
  $home_url = esc_url( home_url('/') );

  if ($is_unsubscribe) {
    $title = $unsubscribe_title;
    $description = $unsubscribe_description;
  } elseif ($is_subscribe) {
    $title = $subscribe_title;
    $description = $subscribe_description;
  }
?>
<!doctype html>
  <html lang="en">
  <head>
    <?php wp_head(); ?>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
  </head>
  <body class="anomate anomate_landing">
    <div class="anomate-unsubscribe<?php if ($is_subscribe || $is_unsubscribe) : ?> anomate-text-center<?php endif; ?>">
      <div class="anomate-unsubscribe__logo">
        <a href="<?php echo esc_attr($home_url); ?>" class="anomate-unsubscribe__logo-link">
          <img src="<?php echo esc_attr($logo); ?>" alt="<?php echo esc_attr($brand_name ?? $brand_name); ?>" class="anomate-unsubscribe__logo-image">
        </a>
      </div>
      <div class="anomate-unsubscribe__head anomate-u-head">
        <h1 class="anomate-email-templates-subtitle-1-semibold anomate-u-head__title"><?php echo esc_attr($title); ?></h1>
        <div class="anomate-email-teplates-paragraph-1-regular anomate-u-head__description"><?php echo esc_attr($description); ?></div>
        <a href="<?php echo esc_attr($home_url); ?>" class="anomate-u-head__return anomate-return">
          <svg xmlns="http://www.w3.org/2000/svg" width="25" height="24" viewBox="0 0 25 24" fill="none" class="anomate-return__icon">
            <path d="M11.8334 7.33334L7.16675 12M7.16675 12L11.8334 16.6667M7.16675 12H17.8334" stroke="currentColor" stroke-width="1.33333" stroke-linecap="round" stroke-linejoin="round"/>
          </svg>
          <span class="anomate-return__text"><?php esc_html_e('Return To Our Website', 'anomate-helper'); ?></span>
        </a>
      </div>
      <form action="<?php echo esc_url( home_url('unsubscribe') ); ?>" class="anomate-unsubscribe__form anomate-u-form<?php if ($is_subscribe || $is_unsubscribe) : ?> anomate-u-form_hidden<?php endif; ?>">
        <input type="email" name="email" id="anomate_email" placeholder="<?php esc_html_e('Your email address*', 'anomate-helper'); ?>" class="anomate-input"<?php if ($subscriber && isset($subscriber->email) && $subscriber->email) : ?> value="<?php echo esc_attr($subscriber->email); ?>"<?php endif; ?> required>
        <?php if ( !empty($marketing_categories) ) : ?>
          <ul class="anomate-u-form__categories anomate-u-categories">
            <?php foreach ($marketing_categories as $marketing_category) : ?>
              <li class="anomate-toggle">
                <input type="checkbox" class="anomate-toggle__input" name="marketingCategories[]" id="marketing_category_<?php echo esc_attr($marketing_category->_id); ?>" value="<?php echo esc_attr($marketing_category->_id); ?>"<?php if ( $not_empty_marketing_categories && in_array($marketing_category->_id, $subscriber->marketingCategories) ) : ?> checked<?php endif; ?>>
                <label for="marketing_category_<?php echo esc_attr($marketing_category->_id); ?>" class="anomate-toggle__label">
                  <div class="anomate-toggle__button">
                    <svg width="40" height="20" viewBox="0 0 40 20" fill="none" xmlns="http://www.w3.org/2000/svg" class="anomate-toggle__icon">
                      <rect x="0.5" y="0.5" width="39" height="19" rx="9.5" fill="white"/>
                      <rect x="0.5" y="0.5" width="39" height="19" rx="9.5" stroke="#ABA3B1"/>
                      <circle cx="10" cy="10" r="7.5" fill="#F5F5F5" stroke="#ABA3B1"/>
                      <circle cx="30" cy="10" r="3.75" stroke="#ABA3B1" stroke-width="0.5"/>
                    </svg>
                  </div>
                  <div class="anomate-toggle__button anomate-toggle__button_active">
                    <svg width="40" height="20" viewBox="0 0 40 20" fill="none" xmlns="http://www.w3.org/2000/svg">
                      <rect x="0.5" y="0.5" width="39" height="19" rx="9.5" fill="white"/>
                      <rect x="0.5" y="0.5" width="39" height="19" rx="9.5" stroke="currentColor"/>
                      <path d="M10 6L10 14" stroke="currentColor" stroke-linecap="round"/>
                      <circle cx="30" cy="10" r="7.5" fill="currentColor" stroke="currentColor"/>
                    </svg>
                  </div>
                  <div class="anomate-email-templates-paragraph-1-medium anomate-toggle__name"><?php echo esc_attr($marketing_category->name); ?></div>
                  <div class="anomate-email-templates-paragrap-2-regular anomate-toggle__description"><?php echo esc_attr($marketing_category->description); ?></div>
                </label>
              </li>
            <?php endforeach; ?>
          </ul>
          <div class="anomate-u-form__buttons">
            <button class="anomate-button anomate-button_ui-button-small" type="submit"><?php esc_html_e('Save preferences', 'anomate-helper'); ?></button>
            <button class="anomate-button anomate-button_secondary anomate-button_ui-button-small anomate-u-form__unsubscribe" type="submit"><?php esc_html_e('Unsubscribe from all', 'anomate-helper'); ?></button>
          </div>
        <?php endif; ?>
        <input type="hidden" name="action" value="anomate_unsubscribe_save_preferences">
        <?php if (isset($get['utm_campaign']) && $get['utm_campaign']) : ?>
          <input type="hidden" name="shopCampaignId" id="anomate_shop_campaign_id" value="<?php echo esc_attr($get['utm_campaign']); ?>">
        <?php endif; ?>
        <?php if (isset($get['acl']) && $get['acl']) : ?>
          <input type="hidden" name="acl" id="anomate_acl" value="<?php echo esc_attr($get['acl']); ?>">
        <?php endif; ?>
        <input type="hidden" name="_wpnonce" id="_wpnonce" value="<?php echo esc_attr( wp_create_nonce('anomate') ); ?>">
      </form>
    </div>
    <?php wp_footer(); ?>
  </body>
</html>